@@ -26,8 +26,9 @@ export default (selector, editing = false) => {
     projectPath,
     schedulesPath,
     settingsLink,
-    userRole,
+    canSetPipelineVariables,
     timezoneData,
+    workerCronExpression,
   } = containerEl.dataset;
 
   return new Vue({
@@ -43,14 +44,14 @@ export default (selector, editing = false) => {
       projectPath,
       schedulesPath,
       settingsLink,
-      userRole,
+      workerCronExpression,
     },
     render(createElement) {
       return createElement(PipelineSchedulesForm, {
         props: {
           timezoneData: JSON.parse(timezoneData),
-          refParam: defaultBranch,
           editing,
+          canSetPipelineVariables: parseBoolean(canSetPipelineVariables),
         },
       });
     },
