@@ -5,6 +5,10 @@ import Suggestion from '@tiptap/suggestion';
 import { PluginKey } from '@tiptap/pm/state';
 import { uniqueId } from 'lodash';
 import { REFERENCE_TYPES } from '~/content_editor/constants/reference_types';
+import {
+  prioritizeCommandsWithFrequent,
+  recordFrequentCommandUsage,
+} from '~/editor/quick_action_suggestions';
 import SuggestionsDropdown from '../components/suggestions_dropdown.vue';
 import { COMMANDS } from '../constants';
 import CodeBlockHighlight from './code_block_highlight';
@@ -15,6 +19,8 @@ import Code from './code';
 const CODE_NODE_TYPES = [CodeBlockHighlight.name, Diagram.name, Frontmatter.name, Code.name];
 
 function expandRangeToIncludeText(range, text, tiptapEditor) {
+  if (!text) return range;
+
   const { state } = tiptapEditor;
   const { from, to: originalTo } = range;
   const maxTo = Math.min(from + text.length, state.doc.content.size);
@@ -63,6 +69,14 @@ function createSuggestionPlugin({
         ];
       }
 
+      // Record frequent command usage for slash-commands
+      if (char === '/') {
+        const name = props?.name || props?.text;
+        if (typeof name === 'string' && name.length > 0) {
+          recordFrequentCommandUsage(name);
+        }
+      }
+
       // Try to expand the range forward to include as much of props.text as possible
       const expandedRange = expandRangeToIncludeText(range, props.text, tiptapEditor);
       tiptapEditor.chain().focus().insertContentAt(expandedRange, content).run();
@@ -80,7 +94,14 @@ function createSuggestionPlugin({
           limit,
           ...options,
         })
-        .search(query);
+        .search(query)
+        .then((data) => {
+          if (!query) {
+            return prioritizeCommandsWithFrequent(data);
+          }
+
+          return data;
+        });
     },
 
     render: () => {
@@ -194,6 +215,7 @@ export default Node.create({
       createPlugin('$', 'reference', REFERENCE_TYPES.SNIPPET),
       createPlugin('~', 'referenceLabel', REFERENCE_TYPES.LABEL, { limit: 100 }),
       createPlugin('&', 'reference', REFERENCE_TYPES.EPIC),
+      createPlugin('[epic:', 'reference', REFERENCE_TYPES.EPIC_ALTERNATIVE),
       createPlugin('!', 'reference', REFERENCE_TYPES.MERGE_REQUEST),
       createPlugin('[vulnerability:', 'reference', REFERENCE_TYPES.VULNERABILITY, {
         filterOnBackend: true,
@@ -214,7 +236,6 @@ export default Node.create({
           [COMMANDS.ASSIGN]: '@',
           [COMMANDS.UNASSIGN]: '@',
           [COMMANDS.REASSIGN]: '@',
-          [COMMANDS.CC]: '@',
           [COMMANDS.ASSIGN_REVIEWER]: '@',
           [COMMANDS.UNASSIGN_REVIEWER]: '@',
           [COMMANDS.REASSIGN_REVIEWER]: '@',
