@@ -1,6 +1,7 @@
 import Vue from 'vue';
 import VueApollo from 'vue-apollo';
 import createDefaultClient from '~/lib/graphql';
+import { parseBoolean } from '~/lib/utils/common_utils';
 import HomepageApp from './components/homepage_app.vue';
 
 Vue.use(VueApollo);
@@ -22,6 +23,7 @@ export default () => {
     mergeRequestsReviewRequestedTitle,
     mergeRequestsYourMergeRequestsTitle,
     lastPushEvent,
+    showFeedbackWidget,
   } = el.dataset;
 
   // Parse lastPushEvent - it's already JSON string from backend
@@ -46,6 +48,7 @@ export default () => {
           assignedWorkItemsPath,
           authoredWorkItemsPath,
           lastPushEvent: parsedLastPushEvent,
+          showFeedbackWidget: parseBoolean(showFeedbackWidget),
         },
       });
     },
