@@ -242,7 +242,7 @@ export const EMPTY_LIST_HELP_URL = helpPagePath('user/packages/package_registry/
 export const PACKAGE_HELP_URL = helpPagePath('user/packages/_index');
 export const NPM_HELP_PATH = helpPagePath('user/packages/npm_registry/_index');
 export const MAVEN_HELP_PATH = helpPagePath('user/packages/maven_repository/_index');
-export const CONAN_HELP_PATH = helpPagePath('user/packages/conan_repository/_index');
+export const CONAN_HELP_PATH = helpPagePath('user/packages/conan_1_repository/_index');
 export const NUGET_HELP_PATH = helpPagePath('user/packages/nuget_repository/_index');
 export const PYPI_HELP_PATH = helpPagePath('user/packages/pypi_repository/_index');
 export const COMPOSER_HELP_PATH = helpPagePath('user/packages/composer_repository/_index');
