@@ -1,8 +1,7 @@
 import Vue from 'vue';
 import VueApollo from 'vue-apollo';
 import { pinia } from '~/pinia/instance';
-import { useFileTreeBrowserVisibility } from '~/repository/stores/file_tree_browser_visibility';
-import { useViewport } from '~/pinia/global_stores/viewport';
+import { useMainContainer } from '~/pinia/global_stores/main_container';
 import FileTreeBrowser from './file_tree_browser.vue';
 
 Vue.use(VueApollo);
@@ -21,11 +20,7 @@ export default async function initFileTreeBrowser(router, options, apolloProvide
     computed: {
       visible() {
         const isProjectOverview = this.$route?.name === 'projectRoot';
-        return (
-          !isProjectOverview &&
-          !useViewport().isCompactViewport &&
-          useFileTreeBrowserVisibility().fileTreeBrowserVisible
-        );
+        return !isProjectOverview && !useMainContainer().isCompact;
       },
     },
     render(h) {
