@@ -2,7 +2,7 @@ import EditorModeSwitcher from './editor_mode_switcher.vue';
 
 export default {
   component: EditorModeSwitcher,
-  title: 'vue_shared/components/markdown/editor_mode_switcher',
+  title: 'vue_shared/markdown/editor_mode_switcher',
 };
 
 const Template = (args, { argTypes }) => ({
