@@ -6,6 +6,8 @@ import AccessorUtilities from '~/lib/utils/accessor';
 import { parseBoolean } from '~/lib/utils/common_utils';
 import { getDraft, updateDraft } from '~/lib/utils/autosave';
 import { TYPE_EPIC, TYPE_ISSUE } from '~/issues/constants';
+import Tracking from '~/tracking';
+
 import {
   DEFAULT_PAGE_SIZE_CHILD_ITEMS,
   NAME_TO_ENUM_MAP,
@@ -183,12 +185,6 @@ export const autocompleteDataSources = (autocompleteSourcesPaths = {}) => {
     sources.mergeRequests = autocompleteSourcesPaths.merge_requests;
   }
 
-  if (gon.features?.extensibleReferenceFilters) {
-    sources.epicsAlternative = autocompleteSourcesPaths.epics;
-    sources.issuesAlternative = autocompleteSourcesPaths.issues;
-    sources.workItems = autocompleteSourcesPaths.issues;
-  }
-
   return sources;
 };
 
@@ -490,3 +486,27 @@ export const preserveDetailsState = (element, descriptionHtml) => {
 };
 
 export const activeWorkItemIds = ref([]);
+
+export const getWorkItemTypeAllowedStatusMap = (workItemTypeNodes) => {
+  const workItemTypeAllowedStatusMap = {};
+
+  workItemTypeNodes.forEach((workItemType) => {
+    const statuses = workItemType.widgetDefinitions?.find(isStatusWidget)?.allowedStatuses;
+    if (statuses) {
+      workItemTypeAllowedStatusMap[workItemType.name.toUpperCase()] = statuses;
+    }
+  });
+
+  return workItemTypeAllowedStatusMap;
+};
+
+/**
+ * Unified method for sending tracking events for work item CRUD component collapse/expand toggles
+ * @param {string} action
+ */
+export function trackCrudCollapse(action) {
+  // eslint-disable-next-line @gitlab/require-i18n-strings
+  const category = 'Work item widget collapse';
+
+  Tracking.event(category, action);
+}
