@@ -8,6 +8,7 @@ class PersonalAccessToken < ApplicationRecord
   include CreatedAtFilterable
   include Gitlab::SQL::Pattern
   include SafelyChangeColumnDefault
+  include PolicyActor
 
   extend ::Gitlab::Utils::Override
 
@@ -17,6 +18,8 @@ class PersonalAccessToken < ApplicationRecord
     sixty_days: 31..60
   }.freeze
 
+  PERSONAL_TOKEN_PREFIX = 'glpat-'
+
   add_authentication_token_field :token,
     digest: true,
     format_with_prefix: :prefix_from_application_current_settings,
@@ -44,10 +47,15 @@ class PersonalAccessToken < ApplicationRecord
   belongs_to :previous_personal_access_token, class_name: 'PersonalAccessToken'
 
   has_many :last_used_ips, class_name: 'Authn::PersonalAccessTokenLastUsedIp'
+  has_many :personal_access_token_granular_scopes, class_name: 'Authz::PersonalAccessTokenGranularScope', autosave: true
+  has_many :granular_scopes, through: :personal_access_token_granular_scopes, class_name: 'Authz::GranularScope'
 
   after_initialize :set_default_scopes, if: :persisted?
   before_save :ensure_token
 
+  before_create :set_user_type
+  before_create :set_group_id
+
   scope :active, -> { not_revoked.not_expired }
   # this scope must use a string condition, otherwise Postgres will not use the correct indices
   scope :expiring_and_not_notified, ->(date) { where(["revoked = false AND expire_notification_delivered = false AND seven_days_notification_sent_at IS NULL AND expires_at >= CURRENT_DATE AND expires_at <= ?", date]) }
@@ -64,14 +72,19 @@ class PersonalAccessToken < ApplicationRecord
   scope :not_revoked, -> { where(revoked: [false, nil]) }
   scope :for_user, ->(user) { where(user: user) }
   scope :for_users, ->(users) { where(user: users) }
+  scope :for_user_types, ->(user_types) { where(user_type: user_types) }
   scope :for_organization, ->(organization) { where(organization_id: organization) }
+  scope :for_group, ->(group) { where(group: group) }
   scope :preload_users, -> { preload(:user) }
-  scope :order_expires_at_asc_id_desc, -> { reorder(expires_at: :asc, id: :desc) }
+  scope :order_name_asc_id_asc, -> { reorder(name: :asc, id: :asc) }
+  scope :order_name_desc_id_desc, -> { reorder(name: :desc, id: :desc) }
+  scope :order_created_at_asc_id_asc, -> { reorder(created_at: :asc, id: :asc) }
+  scope :order_created_at_desc_id_desc, -> { reorder(created_at: :desc, id: :desc) }
+  scope :order_expires_at_asc_id_asc, -> { reorder(expires_at: :asc, id: :asc) }
   scope :order_expires_at_desc_id_desc, -> { reorder(expires_at: :desc, id: :desc) }
-  scope :order_last_used_at_asc_id_desc, -> { reorder(last_used_at: :asc, id: :desc) }
+  scope :order_last_used_at_asc_id_asc, -> { reorder(last_used_at: :asc, id: :asc) }
   scope :order_last_used_at_desc_id_desc, -> { reorder(last_used_at: :desc, id: :desc) }
   scope :project_access_token, -> { includes(:user).references(:user).merge(User.project_bot) }
-  scope :owner_is_human, -> { includes(:user).references(:user).merge(User.human) }
   scope :last_used_before, ->(date) { where("last_used_at <= ?", date) }
   scope :last_used_after, ->(date) { where("last_used_at >= ?", date) }
   scope :expiring_and_not_notified_without_impersonation, -> {
@@ -85,7 +98,11 @@ class PersonalAccessToken < ApplicationRecord
   validate :validate_scopes
   validate :expires_at_before_instance_max_expiry_date, on: :create
 
+  delegate :permitted_for_boundary?, to: :granular_scopes
+
   def revoke!
+    return true if revoked?
+
     if persisted?
       update_columns(revoked: true, updated_at: Time.zone.now)
     else
@@ -101,17 +118,26 @@ class PersonalAccessToken < ApplicationRecord
   def self.simple_sorts
     super.merge(
       {
-        'expires_asc' => -> { order_expires_at_asc_id_desc },
-        'expires_at_asc_id_desc' => -> { order_expires_at_asc_id_desc }, # Keep for backward compatibility
+        'name_asc' => -> { order_name_asc_id_asc },
+        'name_desc' => -> { order_name_desc_id_desc },
+        'created_asc' => -> { order_created_at_asc_id_asc },
+        'created_desc' => -> { order_created_at_desc_id_desc },
+        'expires_asc' => -> { order_expires_at_asc_id_asc },
         'expires_desc' => -> { order_expires_at_desc_id_desc },
-        'last_used_asc' => -> { order_last_used_at_asc_id_desc },
+        'last_used_asc' => -> { order_last_used_at_asc_id_asc },
         'last_used_desc' => -> { order_last_used_at_desc_id_desc }
       }
     )
   end
 
   def self.token_prefix
-    Gitlab::CurrentSettings.current_application_settings.personal_access_token_prefix
+    # Instance wide token prefixes take precedence over the personal_access_token_prefix
+    # See https://gitlab.com/gitlab-org/gitlab/-/issues/388379#note_2477892999
+    if ::Authn::TokenField::PrefixHelper.instance_prefix.blank?
+      Gitlab::CurrentSettings.current_application_settings.personal_access_token_prefix
+    else
+      ::Authn::TokenField::PrefixHelper.prepend_instance_prefix(PERSONAL_TOKEN_PREFIX)
+    end
   end
 
   def self.search(query)
@@ -155,6 +181,16 @@ class PersonalAccessToken < ApplicationRecord
 
   protected
 
+  def set_user_type
+    self.user_type = user.user_type
+  end
+
+  def set_group_id
+    if user.project_bot? && user.bot_namespace&.root_ancestor.is_a?(Group)
+      self.group_id = user.bot_namespace.root_ancestor.id
+    end
+  end
+
   def validate_scopes
     unless revoked || scopes.all? { |scope| Gitlab::Auth.all_available_scopes.include?(scope.to_sym) }
       errors.add :scopes, "can only contain available scopes"
