@@ -47,13 +47,21 @@ module MergeRequests
         notify_about_push(mr)
         mark_mr_as_draft_from_commits(mr)
 
-        execute_mr_web_hooks(mr)
+        # Call merge request webhook with update branches
+        if Feature.disabled?(:split_refresh_worker_web_hooks, @current_user)
+          execute_mr_web_hooks(mr)
+        end
+
+        if Feature.disabled?(:split_refresh_worker_pipeline, @current_user) && !@push.branch_removed?
+          # Run at the end of the loop to avoid any potential contention on the MR object
+          refresh_pipelines_on_merge_requests(mr)
+        end
 
-        # Run at the end of the loop to avoid any potential contention on the MR object
-        refresh_pipelines_on_merge_requests(mr) unless @push.branch_removed?
         merge_request_activity_counter.track_mr_including_ci_config(user: mr.author, merge_request: mr)
       end
 
+      execute_async_workers
+
       true
     end
 
@@ -83,7 +91,7 @@ module MergeRequests
       commit_ids = @commits.map(&:id)
       merge_requests = @project.merge_requests.opened
         .preload_project_and_latest_diff
-        .preload_latest_diff_commit
+        .preload_latest_diff_commit(@project)
         .where(target_branch: @push.branch_name).to_a
         .select(&:diff_head_commit)
         .select do |merge_request|
@@ -342,6 +350,29 @@ module MergeRequests
     def schedule_duo_code_review(merge_request)
       # Overridden in EE
     end
+
+    def execute_async_workers
+      if Feature.enabled?(:split_refresh_worker_web_hooks, @current_user)
+        MergeRequests::Refresh::WebHooksWorker.perform_async(
+          @project.id,
+          @current_user.id,
+          @push.oldrev,
+          @push.newrev,
+          @push.ref
+        )
+      end
+
+      if Feature.enabled?(:split_refresh_worker_pipeline, @current_user)
+        MergeRequests::Refresh::PipelineWorker.perform_async(
+          @project.id,
+          @current_user.id,
+          @push.oldrev,
+          @push.newrev,
+          @push.ref,
+          params.slice(:push_options, :gitaly_context).as_json # ensure sidekiq-compatible hash argument
+        )
+      end
+    end
   end
 end
 
