@@ -9,7 +9,7 @@ module ActiveContext
       #   class MyProcessor
       #     include ActiveContext::Databases::Concerns::Processor
       #
-      #     def self.transform(node)
+      #     def self.transform(collection:, node:, user:)
       #       new.process(node)
       #     end
       #
@@ -29,10 +29,14 @@ module ActiveContext
 
         class_methods do
           # @abstract Implement .transform in subclass to handle query transformation
-          def transform(_node)
+          def transform(collection:, node:, user:)
             raise NotImplementedError, "#{name} must implement .transform"
           end
         end
+
+        def get_embeddings(content, embeddings_version)
+          ActiveContext::Embeddings.generate_embeddings(content, version: embeddings_version, user: user)&.first
+        end
       end
     end
   end
