@@ -5,16 +5,16 @@ module QA
     module Project
       module Settings
         class Runners < Page::Base
-          view 'app/helpers/ci/runners_helper.rb' do
-            element 'runner-status-icon'
+          view 'app/assets/javascripts/ci/runner/components/runner_status_badge.vue' do
+            element 'runner-status-badge'
           end
 
           def has_online_runner?
-            has_element?('runner-status-icon', status: 'online')
+            has_element?('runner-status-badge', status: 'ONLINE')
           end
 
           def has_offline_runner?
-            has_element?('runner-status-icon', status: 'offline')
+            has_element?('runner-status-badge', status: 'OFFLINE')
           end
         end
       end
