@@ -212,11 +212,21 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
         expect(ActiveSession).to receive(:destroy_all_but_current)
         go
       end
+
+      it 'sends the user a notification email' do
+        expect_next_instance_of(NotificationService) do |notification|
+          expect(notification).to receive(:enabled_two_factor).with(user, :otp, {})
+        end
+
+        go
+      end
     end
 
     context 'with invalid pin' do
       before do
         expect(user).to receive(:validate_and_consume_otp!).with(pin).and_return(false)
+
+        allow(NotificationService).to receive(:new)
       end
 
       it 'assigns error' do
@@ -241,6 +251,11 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
         go
         expect(response).to render_template(:show)
       end
+
+      it 'does not send a notification email' do
+        go
+        expect(NotificationService).not_to have_received(:new)
+      end
     end
 
     it_behaves_like 'user must enter a valid current password'
@@ -300,9 +315,18 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
     def challenge
       @_challenge ||= begin
         options_for_create = WebAuthn::Credential.options_for_create(
-          user: { id: user.webauthn_xid, name: user.username },
-          authenticator_selection: { user_verification: 'discouraged' },
-          rp: { name: 'GitLab' }
+          user: {
+            id: user.webauthn_xid,
+            name: user.username,
+            display_name: user.name
+          },
+          exclude: user.get_all_webauthn_credential_ids,
+          authenticator_selection: {
+            user_verification: 'discouraged',
+            resident_key: 'preferred'
+          },
+          rp: { name: 'GitLab' },
+          extensions: { credProps: true }
         )
         options_for_create.challenge
       end
@@ -317,6 +341,35 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
       expect(user.failed_attempts).to be_eql(1)
     end
 
+    context 'when it sets ups its view form' do
+      it 'renders relevant view variables (2FA & Passkeys)', :freeze_time do
+        stored_second_factor_webauthn_registration = create(:webauthn_registration, user: user)
+        stored_passkey = create(:webauthn_registration, :passkey, user: user)
+
+        go
+
+        rendered_second_factor_webauthn_registration = assigns[:registrations].first
+        rendered_passkey = assigns[:passkeys].first
+
+        expect(assigns[:registrations].count).to eq(user.second_factor_webauthn_registrations.count)
+        expect(rendered_second_factor_webauthn_registration[:name]).to eq(
+          stored_second_factor_webauthn_registration.name
+        )
+        expect(rendered_second_factor_webauthn_registration[:created_at]).to eq(
+          stored_second_factor_webauthn_registration.created_at
+        )
+        expect(rendered_second_factor_webauthn_registration[:delete_path]).to eq(
+          destroy_webauthn_profile_two_factor_auth_path(stored_second_factor_webauthn_registration)
+        )
+
+        expect(assigns[:passkeys].count).to eq(user.passkeys.count)
+        expect(rendered_passkey[:name]).to eq(stored_passkey.name)
+        expect(rendered_passkey[:created_at]).to eq(stored_passkey.created_at)
+        expect(rendered_passkey[:last_used_at]).to eq(stored_passkey.last_used_at)
+        expect(rendered_passkey[:delete_path]).to eq(profile_passkey_path(stored_passkey))
+      end
+    end
+
     context "when valid password is given" do
       it "registers and render OTP backup codes" do
         post :create_webauthn, params: params_with_password
@@ -330,6 +383,25 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
         expect(response).to redirect_to(profile_two_factor_auth_path)
         expect(flash[:notice]).to match(/Your WebAuthn device was registered!/)
       end
+
+      it 'sends the user a notification email' do
+        expect_next_instance_of(NotificationService) do |notification|
+          expect(notification).to receive(:enabled_two_factor).with(user, :webauthn, { device_name: 'touch id' })
+        end
+
+        post :create_webauthn, params: params_with_password
+      end
+    end
+
+    context 'when an invalid password is given' do
+      before do
+        allow(NotificationService).to receive(:new)
+      end
+
+      it 'does not send a notification email' do
+        post :create_webauthn, params: params
+        expect(NotificationService).not_to have_received(:new)
+      end
     end
   end
 
@@ -424,6 +496,25 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
       end
 
       it_behaves_like 'user must enter a valid current password'
+
+      it 'sends the user a notification email' do
+        expect_next_instance_of(NotificationService) do |notification|
+          expect(notification).to receive(:disabled_two_factor).with(user, :otp)
+        end
+
+        go
+      end
+
+      context 'when an invalid password is given' do
+        before do
+          allow(NotificationService).to receive(:new)
+        end
+
+        it 'does not send a notification email' do
+          delete :destroy_otp, params: { current_password: 'invalid' }
+          expect(NotificationService).not_to have_received(:new)
+        end
+      end
     end
 
     context 'for a user that has only WebAuthn enabled' do
@@ -464,7 +555,9 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
       create(:user, :two_factor_via_webauthn)
     end
 
-    let(:webauthn_id) { user.webauthn_registrations.first.id }
+    let(:webauthn_registration) { user.second_factor_webauthn_registrations.first }
+    let(:webauthn_id) { webauthn_registration.id }
+    let(:webauthn_name) { webauthn_registration.name }
     let(:current_password) { user.password }
     let(:destroy_webauthn) do
       delete :destroy_webauthn, params: { id: webauthn_id, current_password: current_password }
@@ -475,11 +568,11 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
     end
 
     it 'destroys the webauthn device' do
-      count = user.webauthn_registrations.count
+      count = user.second_factor_webauthn_registrations.count
       go
 
       user.reload
-      expect(user.webauthn_registrations.count).to eq(count - 1)
+      expect(user.second_factor_webauthn_registrations.count).to eq(count - 1)
     end
 
     it 'redirects to the profile two factor authentication page' do
@@ -488,16 +581,56 @@ RSpec.describe Profiles::TwoFactorAuthsController, feature_category: :system_acc
       expect(response).to redirect_to profile_two_factor_auth_path
     end
 
+    it 'displays a notice on success' do
+      go
+
+      expect(flash[:notice]).to eq _('Successfully deleted WebAuthn device.')
+    end
+
     it 'calls the Webauthn::DestroyService' do
       service = double
 
       expect(Webauthn::DestroyService).to receive(:new).with(user, user, webauthn_id.to_s).and_return(service)
-      expect(service).to receive(:execute)
+      expect(service).to receive(:execute).and_return(ServiceResponse.success)
 
       go
     end
 
     it_behaves_like 'user must enter a valid current password'
+
+    it 'sends the user a notification email' do
+      expect_next_instance_of(NotificationService) do |notification|
+        expect(notification).to receive(:disabled_two_factor).with(user, :webauthn, { device_name: webauthn_name })
+      end
+
+      go
+    end
+
+    context 'when an invalid password is given' do
+      let(:current_password) { 'invalid' }
+
+      before do
+        allow(NotificationService).to receive(:new)
+      end
+
+      it 'does not send a notification email' do
+        go
+        expect(NotificationService).not_to have_received(:new)
+      end
+    end
+
+    context 'when it fails to delete' do
+      it 'returns an error message' do
+        expect_next_instance_of(Webauthn::DestroyService) do |service|
+          expect(service).to receive(:execute).and_return({ status: :error, message: 'an error occurred' })
+        end
+
+        go
+
+        expect(response).to redirect_to(profile_two_factor_auth_path)
+        expect(flash[:alert]).to eq('an error occurred')
+      end
+    end
   end
 
   describe 'PATCH skip' do
