@@ -6,8 +6,13 @@ FactoryBot.define do
     namespace
     permissions { [:create_issue] }
 
-    trait :instance do
+    trait :standalone do
       namespace { nil }
     end
+
+    trait :all_membership_namespaces do
+      namespace { nil }
+      all_membership_namespaces { true }
+    end
   end
 end
