@@ -50,6 +50,21 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
         end
       end
 
+      it 'change deletion settings', :js do
+        within_testid('admin-visibility-access-settings') do
+          fill_in 'Retention period', with: 30
+          uncheck 'Allow immediate deletion'
+          click_button 'Save changes'
+        end
+
+        expect(page).to have_content 'Application settings saved successfully'
+
+        within_testid('admin-visibility-access-settings') do
+          expect(find_field('Retention period').value).to eq('30')
+          expect(find_field('Allow immediate deletion')).not_to be_checked
+        end
+      end
+
       it 'modify import sources' do
         expect(current_settings.import_sources).to be_empty
 
@@ -355,16 +370,16 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
         expect(current_settings.terminal_max_session_time).to eq(15)
       end
 
-      context 'Configure Gitpod' do
-        it 'changes gitpod settings' do
+      context 'Configure Ona' do
+        it 'changes ona settings' do
           page.within('#js-gitpod-settings') do
-            check 'Enable Gitpod integration'
-            fill_in 'Gitpod URL', with: 'https://gitpod.test/'
+            check 'Enable Ona integration'
+            fill_in 'Ona URL', with: 'https://ona.test/'
             click_button 'Save changes'
           end
 
           expect(page).to have_content 'Application settings saved successfully'
-          expect(current_settings.gitpod_url).to eq('https://gitpod.test/')
+          expect(current_settings.gitpod_url).to eq('https://ona.test/')
           expect(current_settings.gitpod_enabled).to be(true)
         end
       end
@@ -460,6 +475,31 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
           end
         end
       end
+
+      context 'Web IDE Settings' do
+        it 'changes and restores web ide extension host domain setting' do
+          default_host_domain = ::WebIde::ExtensionMarketplace::DEFAULT_EXTENSION_HOST_DOMAIN
+
+          page.within('#js-web-ide-settings') do
+            expect(page).to have_field('Extension host domain', with: default_host_domain)
+
+            fill_in 'Extension host domain', with: 'example.com'
+            click_button 'Save changes'
+          end
+
+          expect(page).to have_content 'Application settings saved successfully'
+          expect(current_settings.vscode_extension_marketplace_extension_host_domain)
+            .to eq('example.com')
+
+          page.within('#js-web-ide-settings') do
+            click_link 'Restore default domain'
+          end
+
+          expect(page).to have_content 'The Web IDE extension host domain was restored to its default value.'
+          expect(current_settings.vscode_extension_marketplace_extension_host_domain)
+            .to eq(default_host_domain)
+        end
+      end
     end
 
     context 'Integrations page' do
@@ -574,10 +614,12 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
         end
       end
 
-      context 'Runner Registration' do
-        it 'allows admins to control who has access to register runners' do
+      context 'Runners' do
+        before do
           visit ci_cd_admin_application_settings_path
+        end
 
+        it 'allows admins to control who has access to register runners' do
           expect(current_settings.valid_runner_registrars).to eq(ApplicationSetting::VALID_RUNNER_REGISTRAR_TYPES)
 
           within_testid('runner-settings') do
@@ -589,6 +631,36 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
           expect(current_settings.valid_runner_registrars).to eq([])
           expect(page).to have_content 'Application settings saved successfully'
         end
+
+        it 'changes `/jobs/request` rate limits settings' do
+          within_testid('runner-settings') do
+            fill_in 'Maximum requests per minute to the POST /jobs/request endpoint', with: 0
+            click_button 'Save changes'
+          end
+
+          expect(page).to have_content 'Application settings saved successfully'
+          expect(current_settings.runner_jobs_request_api_limit).to eq(0)
+        end
+
+        it 'changes `PATCH /jobs/:id/trace` rate limits settings' do
+          within_testid('runner-settings') do
+            fill_in 'Maximum requests per minute to the PATCH /jobs/:id/trace endpoint', with: 0
+            click_button 'Save changes'
+          end
+
+          expect(page).to have_content 'Application settings saved successfully'
+          expect(current_settings.runner_jobs_patch_trace_api_limit).to eq(0)
+        end
+
+        it 'changes Runner Jobs rate limits settings' do
+          within_testid('runner-settings') do
+            fill_in 'Maximum requests per minute to other Runner Jobs API endpoints', with: 0
+            click_button 'Save changes'
+          end
+
+          expect(page).to have_content 'Application settings saved successfully'
+          expect(current_settings.runner_jobs_endpoints_api_limit).to eq(0)
+        end
       end
 
       context 'Job token permissions' do
@@ -1173,6 +1245,16 @@ RSpec.describe 'Admin updates settings', feature_category: :shared do
           it_behaves_like 'API rate limit setting'
         end
 
+        context 'for GET /projects/:id/members/all API requests' do
+          let_it_be(:rate_limit_field) do
+            format(_('Maximum requests to the %{api_name} API per %{timeframe} per user or IP address'), api_name: 'GET /projects/:id/members/all', timeframe: 'minute')
+          end
+
+          let_it_be(:application_setting_key) { :project_members_api_limit }
+
+          it_behaves_like 'API rate limit setting'
+        end
+
         context 'for GET /projects/:id/invited_groups API requests' do
           let_it_be(:rate_limit_field) do
             format(_('Maximum requests to the %{api_name} API per %{timeframe} per user or IP address'), api_name: 'GET /projects/:id/invited_groups', timeframe: 'minute')
