@@ -14,9 +14,6 @@ RSpec.describe "User creates issue", :js, feature_category: :team_planning do
     # we won't need the tests for the issues listing page, since we'll be using
     # the work items listing page.
     stub_feature_flags(work_item_planning_view: false)
-    stub_feature_flags(work_item_view_for_issues: true)
-    stub_feature_flags(work_items_alpha: false)
-    stub_feature_flags(work_items_project_issues_list: false)
   end
 
   context "when unauthenticated" do
