@@ -160,7 +160,7 @@ RSpec.describe 'User searches for issues', :js, :clean_gitlab_redis_rate_limitin
       it 'is redirected to login page' do
         visit(search_path)
 
-        expect(page).to have_content('You need to sign in or sign up before continuing.')
+        expect(page).to have_content('Sign in or sign up before continuing.')
       end
     end
   end
