@@ -7,22 +7,24 @@ import { mockTracking, triggerEvent } from 'helpers/tracking_helper';
 import DiffFileHeader from '~/diffs/components/diff_file_header.vue';
 import { DIFF_FILE_AUTOMATIC_COLLAPSE, DIFF_FILE_MANUAL_COLLAPSE } from '~/diffs/constants';
 import { diffViewerModes } from '~/ide/constants';
-import { scrollToElement } from '~/lib/utils/common_utils';
+import { scrollToElement } from '~/lib/utils/scroll_utils';
 import { truncateSha } from '~/lib/utils/text_utility';
 import { sprintf } from '~/locale';
 import ClipboardButton from '~/vue_shared/components/clipboard_button.vue';
 import { useLegacyDiffs } from '~/diffs/stores/legacy_diffs';
 import { globalAccessorPlugin } from '~/pinia/plugins';
 import { useNotes } from '~/notes/store/legacy_notes';
+import diffsEventHub from '~/diffs/event_hub';
 import diffDiscussionsMockData from '../mock_data/diff_discussions';
 
 jest.mock('~/lib/utils/common_utils', () => ({
   convertObjectPropsToCamelCase: jest.requireActual('~/lib/utils/common_utils')
     .convertObjectPropsToCamelCase,
   isInMRPage: jest.requireActual('~/lib/utils/common_utils').isInMRPage,
-  scrollToElement: jest.fn(),
   isLoggedIn: () => true,
 }));
+jest.mock('~/lib/utils/scroll_utils');
+jest.mock('~/diffs/event_hub');
 
 const createDiffFile = () => ({
   ...diffDiscussionsMockData.diff_file,
@@ -119,6 +121,15 @@ describe('DiffFileHeader component', () => {
     expect(wrapper.emitted().toggleFile).toBeDefined();
   });
 
+  it('when header is clicked it emits setFileActive', async () => {
+    createComponent();
+    findHeader().trigger('click');
+
+    await nextTick();
+
+    expect(diffsEventHub.$emit).toHaveBeenCalledWith('setFileActive', 'xyz');
+  });
+
   it('when header is clicked it triggers the action that removes the value that forces a file to be uncollapsed', () => {
     createComponent();
     findHeader().trigger('click');
