@@ -1247,10 +1247,9 @@ describe('GfmAutoComplete', () => {
     });
   });
 
-  describe('Extensible reference filters', () => {
+  describe('[issue: and [work_item:', () => {
     const dataSources = {
-      issuesAlternative: `${TEST_HOST}/autocomplete_sources/issues`,
-      workItems: `${TEST_HOST}/autocomplete_sources/issues`,
+      issues: `${TEST_HOST}/autocomplete_sources/issues`,
     };
 
     let autocomplete;
@@ -1275,48 +1274,27 @@ describe('GfmAutoComplete', () => {
       };
     };
 
+    beforeEach(() => {
+      setup();
+    });
+
     afterEach(() => {
       autocomplete.destroy();
       resetHTMLFixture();
     });
 
-    describe('when extensible_reference_filters feature flag enabled', () => {
-      beforeEach(() => {
-        gon.features = { extensibleReferenceFilters: true };
-        setup();
-      });
-
-      it('[issue: shows issues', () => {
-        triggerDropdown($textarea, '[issue:');
-        const issues = getIssueDropdownItems();
-        expect(issues).toHaveLength(mockIssues.length);
-        expect(issues).toEqual(mockIssues.map(issueMatcher));
-      });
-
-      it('[work_item: shows work items', () => {
-        triggerDropdown($textarea, '[work_item:');
-        const workItems = getWorkItemDropdownItems();
-        expect(workItems).toHaveLength(mockIssues.length);
-        expect(workItems).toEqual(mockIssues.map(issueMatcher));
-      });
+    it('[issue: shows issues', () => {
+      triggerDropdown($textarea, '[issue:');
+      const issues = getIssueDropdownItems();
+      expect(issues).toHaveLength(mockIssues.length);
+      expect(issues).toEqual(mockIssues.map(issueMatcher));
     });
 
-    describe('when extensible_reference_filters feature flag disabled', () => {
-      beforeEach(() => {
-        gon.features = { extensibleReferenceFilters: false };
-        setup();
-      });
-
-      it('[issue: does not show issues', () => {
-        triggerDropdown($textarea, '[issue:');
-        const dropdownElement = document.getElementById(issueDropdownElementId);
-        expect(dropdownElement).toBe(null);
-      });
-
-      it('[work_item: does not show work items', () => {
-        const dropdownElement = document.getElementById(workItemDropdownElementId);
-        expect(dropdownElement).toBe(null);
-      });
+    it('[work_item: shows work items', () => {
+      triggerDropdown($textarea, '[work_item:');
+      const workItems = getWorkItemDropdownItems();
+      expect(workItems).toHaveLength(mockIssues.length);
+      expect(workItems).toEqual(mockIssues.map(issueMatcher));
     });
   });
 
