@@ -3,19 +3,20 @@ import { GlFormInput, GlIcon, GlTooltip } from '@gitlab/ui';
 import VueApollo from 'vue-apollo';
 import { cloneDeep } from 'lodash';
 import { PiniaVuePlugin } from 'pinia';
+import { createTestingPinia } from '@pinia/testing';
 import waitForPromises from 'helpers/wait_for_promises';
 import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
-import { RecycleScroller } from 'vendor/vue-virtual-scroller';
+import { useMockIntersectionObserver } from 'helpers/mock_dom_observer';
 import TreeList from '~/repository/file_tree_browser/components/tree_list.vue';
 import FileRow from '~/vue_shared/components/file_row.vue';
 import { FOCUS_FILE_TREE_BROWSER_FILTER_BAR, keysFor } from '~/behaviors/shortcuts/keybindings';
 import { shouldDisableShortcuts } from '~/behaviors/shortcuts/shortcuts_toggle';
-import { stubComponent } from 'helpers/stub_component';
 import createMockApollo from 'helpers/mock_apollo_helper';
 import { useMockInternalEventsTracking } from 'helpers/tracking_internal_events_helper';
 import paginatedTreeQuery from 'shared_queries/repository/paginated_tree.query.graphql';
 import { Mousetrap } from '~/lib/mousetrap';
 import FileTreeBrowserToggle from '~/repository/file_tree_browser/components/file_tree_browser_toggle.vue';
+import * as utils from '~/repository/file_tree_browser/utils';
 import { mockResponse } from '../mock_data';
 
 Vue.use(VueApollo);
@@ -31,44 +32,40 @@ describe('Tree List', () => {
   let pinia;
   let getQueryHandlerSuccess;
 
+  const { trigger: triggerIntersection } = useMockIntersectionObserver();
+  const triggerIntersectionForAll = () => {
+    const listItems = wrapper.element.querySelectorAll('[data-item-id]');
+    listItems.forEach((item) => {
+      triggerIntersection(item, { entry: { isIntersecting: true } });
+    });
+  };
+
   const createComponent = async (apiResponse = mockResponse) => {
     getQueryHandlerSuccess = jest.fn().mockResolvedValue(apiResponse);
 
     apolloProvider = createMockApollo([[paginatedTreeQuery, getQueryHandlerSuccess]]);
 
-    const recycleScrollerStub = stubComponent(
-      {
-        name: 'RecycleScroller',
-        props: {
-          items: { type: Array, required: true },
-          itemSize: { type: Number, required: true },
-          buffer: { type: Number, required: true },
-          keyField: { type: String, required: true },
-        },
-      },
-      {
-        template: `<div><slot v-for="(item, index) in items" :item="item" :index="index"></slot></div>`,
-      },
-    );
-
     wrapper = shallowMountExtended(TreeList, {
       apolloProvider,
       pinia,
       propsData: { projectPath: 'group/project', currentRef: 'main', refType: 'branch' },
       mocks: { $route: { params: {}, $apollo: { query: jest.fn() } } },
-      stubs: { RecycleScroller: recycleScrollerStub },
     });
 
     await waitForPromises();
+    triggerIntersectionForAll();
   };
 
-  beforeEach(() => createComponent());
+  beforeEach(() => {
+    pinia = createTestingPinia();
+    return createComponent();
+  });
 
   const findFileTreeToggle = () => wrapper.findComponent(FileTreeBrowserToggle);
-
+  const findTree = () => wrapper.find('[role="tree"]');
   const findHeader = () => wrapper.find('h3');
-  const findRecycleScroller = () => wrapper.findComponent(RecycleScroller);
   const findFileRows = () => wrapper.findAllComponents(FileRow);
+  const findFileRowPlaceholders = () => wrapper.findAll('[data-placeholder-item]');
   const findFilterInput = () => wrapper.findComponent(GlFormInput);
   const findFilterIcon = () => wrapper.findComponent(GlIcon);
   const findNoFilesMessage = () => wrapper.findByText('No files found');
@@ -95,33 +92,6 @@ describe('Tree List', () => {
     expect(findFileTreeToggle().exists()).toBe(true);
   });
 
-  it('renders recycle-scroller with correct props', () => {
-    const scroller = findRecycleScroller();
-    expect(scroller.props('items')).toEqual([
-      {
-        id: '/dir_1/dir_2-gid://123-0',
-        level: 0,
-        loading: false,
-        name: 'dir_2',
-        opened: false,
-        path: '/dir_1/dir_2',
-        routerPath: '/-/tree/main//dir_1/dir_2',
-        type: 'tree',
-      },
-      {
-        fileHash: 'abc123',
-        id: '/dir_1/file.txt-gid://456-0',
-        level: 0,
-        mode: '100644',
-        name: 'file.txt',
-        path: '/dir_1/file.txt',
-        routerPath: '/-/blob/main//dir_1/file.txt',
-      },
-    ]);
-
-    expect(scroller.props()).toMatchObject({ itemSize: 32, buffer: 100, keyField: 'id' });
-  });
-
   it('renders file rows with correct props', () => {
     const fileRows = findFileRows();
 
@@ -154,11 +124,56 @@ describe('Tree List', () => {
     });
   });
 
-  it('calls toggleDirectory with correct path when clickTree is emitted from FileRow', () => {
-    const toggleDirectory = jest.spyOn(wrapper.vm, 'toggleDirectory').mockImplementation(() => {});
-    const path = '/dir_1/dir_2';
-    findFileRows().at(0).vm.$emit('clickTree', path);
-    expect(toggleDirectory).toHaveBeenCalledWith(path);
+  it('fetches directory contents when tree row is clicked', async () => {
+    const subdirResponse = cloneDeep(mockResponse);
+    subdirResponse.data.project.repository.paginatedTree.nodes[0].trees.nodes = [];
+    subdirResponse.data.project.repository.paginatedTree.nodes[0].blobs.nodes = [];
+    getQueryHandlerSuccess.mockResolvedValueOnce(subdirResponse);
+
+    findFileRows().at(0).vm.$emit('clickTree');
+    await waitForPromises();
+
+    expect(getQueryHandlerSuccess).toHaveBeenLastCalledWith(
+      expect.objectContaining({ path: 'dir_1/dir_2' }),
+    );
+  });
+
+  it.each`
+    toggleClose  | expectedOpened | description
+    ${true}      | ${false}       | ${'collapses'}
+    ${false}     | ${true}        | ${'stays expanded'}
+    ${undefined} | ${false}       | ${'collapses (default behavior)'}
+  `(
+    '$description when clicked with toggleClose: $toggleClose',
+    async ({ toggleClose, expectedOpened }) => {
+      await createComponent();
+      const subdirResponse = cloneDeep(mockResponse);
+      subdirResponse.data.project.repository.paginatedTree.nodes[0].trees.nodes = [];
+      subdirResponse.data.project.repository.paginatedTree.nodes[0].blobs.nodes = [];
+      getQueryHandlerSuccess.mockResolvedValueOnce(subdirResponse);
+
+      findFileRows().at(0).vm.$emit('clickTree');
+      await waitForPromises();
+
+      expect(findFileRows().at(0).props('file').opened).toBe(true);
+
+      const options = toggleClose === undefined ? undefined : { toggleClose };
+      findFileRows().at(0).vm.$emit('clickTree', options);
+      await nextTick();
+
+      expect(findFileRows().at(0).props('file').opened).toBe(expectedOpened);
+    },
+  );
+
+  it('sets aria-setsize and aria-posinset relative to siblings at same level', async () => {
+    await createComponent();
+    const treeItems = wrapper.findAll('[role="treeitem"]');
+
+    expect(treeItems.at(0).attributes('aria-setsize')).toBe('2');
+    expect(treeItems.at(0).attributes('aria-posinset')).toBe('1');
+
+    expect(treeItems.at(1).attributes('aria-setsize')).toBe('2');
+    expect(treeItems.at(1).attributes('aria-posinset')).toBe('2');
   });
 
   describe('pagination', () => {
@@ -169,11 +184,31 @@ describe('Tree List', () => {
     });
 
     it('renders a show more button when hasNextPage is true', () => {
-      expect(findRecycleScroller().props('items')[2]).toMatchObject({ isShowMore: true });
+      expect(findFileRows().at(2).props('file')).toMatchObject({ isShowMore: true });
     });
 
-    it('fetches the next page', () => {
-      findFileRows().at(2).vm.$emit('showMore');
+    it('fetches the next page', async () => {
+      const secondPageResponse = cloneDeep(mockResponse);
+      secondPageResponse.data.project.repository.paginatedTree.nodes[0].trees.nodes = [];
+      secondPageResponse.data.project.repository.paginatedTree.nodes[0].blobs.nodes = [];
+      getQueryHandlerSuccess.mockResolvedValueOnce(secondPageResponse);
+
+      const mockFocus = jest.fn();
+      const mockEvent = {
+        target: {
+          closest: jest.fn(() => ({
+            previousElementSibling: {
+              nextElementSibling: {
+                firstElementChild: { focus: mockFocus },
+              },
+            },
+          })),
+        },
+      };
+
+      findFileRows().at(2).vm.$emit('showMore', mockEvent);
+
+      await waitForPromises();
 
       expect(getQueryHandlerSuccess).toHaveBeenCalledWith({
         projectPath: 'group/project',
@@ -183,6 +218,19 @@ describe('Tree List', () => {
         nextPageCursor: 'cursor123',
         pageSize: 100,
       });
+
+      expect(mockFocus).toHaveBeenCalled();
+    });
+
+    it('can filter with Show more button in the list', async () => {
+      const filterQuery = '/dir_1/dir_2';
+      expect(findFileRows()).toHaveLength(3); // Contains all items before filtering
+
+      findFilterInput().vm.$emit('input', filterQuery);
+      await nextTick();
+
+      expect(findFileRows()).toHaveLength(1); // Contains only one item after filtering
+      expect(findFileRows().at(0).props('file')).toMatchObject({ path: filterQuery });
     });
   });
 
@@ -325,9 +373,7 @@ describe('Tree List', () => {
   describe('deep path navigation with pagination', () => {
     it('paginates to find directories not on first page', async () => {
       const page1 = cloneDeep(mockResponse);
-      page1.data.project.repository.paginatedTree.nodes[0].trees.nodes = [
-        { id: 'gid://dir_1', name: 'dir_1', path: 'dir_1', webPath: 'dir_1' },
-      ];
+      page1.data.project.repository.paginatedTree.nodes[0].blobs.nodes = [];
       page1.data.project.repository.paginatedTree.pageInfo = {
         __typename: 'PageInfo',
         hasNextPage: true,
@@ -377,9 +423,9 @@ describe('Tree List', () => {
           startCursor: null,
           endCursor: `cursor_${i}`,
         };
-        page.data.project.repository.paginatedTree.nodes[0].trees.nodes = [
-          { id: `gid://dir_${i}`, name: `dir_${i}`, path: `dir_${i}`, webPath: `dir_${i}` },
-        ];
+
+        page.data.project.repository.paginatedTree.nodes[0].blobs.nodes = [];
+        page.data.project.repository.paginatedTree.nodes[0].trees.nodes = [];
         getQueryHandlerSuccess.mockResolvedValueOnce(page);
       }
 
@@ -406,4 +452,76 @@ describe('Tree List', () => {
       expect(getQueryHandlerSuccess).toHaveBeenCalledTimes(2); // root + dir_0
     });
   });
+
+  describe('keyboard navigation', () => {
+    it('calls handleTreeKeydown when keydown is triggered on tree', async () => {
+      jest.spyOn(utils, 'handleTreeKeydown');
+      await createComponent();
+
+      findTree().trigger('keydown', { key: 'ArrowDown' });
+
+      expect(utils.handleTreeKeydown).toHaveBeenCalledWith(
+        expect.objectContaining({ type: 'keydown', key: 'ArrowDown' }),
+      );
+    });
+  });
+
+  describe('Tree toggle', () => {
+    it('passes show-tree-toggle="true" prop to all FileRow components', () => {
+      findFileRows().wrappers.forEach((fileRow) =>
+        expect(fileRow.props('showTreeToggle')).toBe(true),
+      );
+    });
+
+    it('fetches directory contents when chevron is clicked', async () => {
+      const subdirResponse = cloneDeep(mockResponse);
+      subdirResponse.data.project.repository.paginatedTree.nodes[0].blobs.nodes = [
+        {
+          id: 'gid://file1',
+          name: 'subfile.txt',
+          path: 'dir_1/dir_2/subfile.txt',
+          sha: 'xyz789',
+          webPath: 'dir_1/dir_2/subfile.txt',
+        },
+      ];
+      getQueryHandlerSuccess.mockResolvedValueOnce(subdirResponse);
+
+      const treeFileRow = findFileRows().at(0); // First row is the tree based on mockResponse
+      treeFileRow.vm.$emit('clickTree', treeFileRow.props('file').path);
+
+      await waitForPromises();
+
+      expect(getQueryHandlerSuccess).toHaveBeenLastCalledWith(
+        expect.objectContaining({ path: 'dir_1/dir_2' }),
+      );
+    });
+  });
+
+  describe('intersection observer', () => {
+    it('renders placeholders before intersection and FileRows after', async () => {
+      getQueryHandlerSuccess = jest.fn().mockResolvedValue(mockResponse);
+      apolloProvider = createMockApollo([[paginatedTreeQuery, getQueryHandlerSuccess]]);
+
+      wrapper = shallowMountExtended(TreeList, {
+        apolloProvider,
+        pinia,
+        propsData: { projectPath: 'group/project', currentRef: 'main', refType: 'branch' },
+        mocks: { $route: { params: {} } },
+      });
+
+      await waitForPromises();
+      await nextTick();
+
+      // Before intersection: placeholders only
+      expect(findFileRowPlaceholders()).toHaveLength(2);
+      expect(findFileRows()).toHaveLength(0);
+
+      // After intersection: FileRows rendered
+      triggerIntersectionForAll();
+      await nextTick();
+
+      expect(findFileRows()).toHaveLength(2);
+      expect(findFileRowPlaceholders()).toHaveLength(0);
+    });
+  });
 });
