@@ -394,6 +394,17 @@ export const POLICIES_BY_RESOURCE = [
       },
     ],
   },
+  {
+    resource: { value: 'MERGE_REQUESTS', text: 'Merge requests' },
+    policies: [
+      { value: '', text: 'None' },
+      {
+        value: 'READ_MERGE_REQUESTS',
+        text: 'Read',
+        resource: { value: 'MERGE_REQUESTS', text: 'Merge requests' },
+      },
+    ],
+  },
   {
     resource: { value: 'PACKAGES', text: 'Packages' },
     policies: [
@@ -442,6 +453,17 @@ export const POLICIES_BY_RESOURCE = [
       },
     ],
   },
+  {
+    resource: { value: 'REPOSITORIES', text: 'Repositories' },
+    policies: [
+      { value: '', text: 'None' },
+      {
+        value: 'READ_REPOSITORIES',
+        text: 'Read',
+        resource: { value: 'REPOSITORIES', text: 'Repositories' },
+      },
+    ],
+  },
   {
     resource: { value: 'SECURE_FILES', text: 'Secure files' },
     policies: [
@@ -474,4 +496,15 @@ export const POLICIES_BY_RESOURCE = [
       },
     ],
   },
+  {
+    resource: { value: 'WORK_ITEMS', text: 'Work items' },
+    policies: [
+      { value: '', text: 'None' },
+      {
+        value: 'READ_WORK_ITEMS',
+        text: 'Read',
+        resource: { value: 'WORK_ITEMS', text: 'Work items' },
+      },
+    ],
+  },
 ];
