@@ -9,6 +9,7 @@ import {
 } from '@gitlab/ui';
 import { mount, shallowMount } from '@vue/test-utils';
 import MockAdapter from 'axios-mock-adapter';
+import * as urlUtils from '~/lib/utils/url_utility';
 import axios from '~/lib/utils/axios_utils';
 import { mockTracking } from 'helpers/tracking_helper';
 import { extendedWrapper } from 'helpers/vue_test_utils_helper';
@@ -133,6 +134,8 @@ describe('WikiForm', () => {
   }
 
   beforeEach(() => {
+    jest.spyOn(urlUtils, 'getParameterByName').mockReturnValue(null);
+
     trackingSpy = mockTracking(undefined, null, jest.spyOn);
     mock = new MockAdapter(axios);
   });
@@ -152,7 +155,6 @@ describe('WikiForm', () => {
         renderMarkdownPath: pageInfoPersisted.markdownPreviewPath,
         uploadsPath: pageInfoPersisted.uploadsPath,
         autofocus: pageInfoPersisted.persisted,
-        markdownDocsPath: pageInfoPersisted.markdownHelpPath,
       }),
     );
 
@@ -350,9 +352,7 @@ describe('WikiForm', () => {
   it('shows correct link for wiki specific markdown docs', () => {
     createWrapper({ mountFn: mount });
 
-    expect(findMarkdownHelpLink().attributes().href).toBe(
-      '/help/user/markdown#wiki-specific-markdown',
-    );
+    expect(findMarkdownHelpLink().attributes().href).toBe('/help/user/project/wiki/markdown#links');
   });
 
   describe('when wiki content is updated', () => {
