@@ -154,23 +154,6 @@ describe('autocompleteDataSources', () => {
       });
     });
   });
-
-  describe('when extensibleReferenceFilters is enabled', () => {
-    it('returns paths with issuesAlternative and workItems included', () => {
-      gon.features = { extensibleReferenceFilters: true };
-
-      expect(autocompleteDataSources(pathsWithCamelCase)).toEqual({
-        ...pathsWithCamelCase,
-        statuses: true,
-        epicsAlternative:
-          '/flightjs/Flight/-/autocomplete_sources/epics?type=WorkItem&work_item_type_id=1',
-        issuesAlternative:
-          '/flightjs/Flight/-/autocomplete_sources/issues?type=WorkItem&work_item_type_id=1',
-        workItems:
-          '/flightjs/Flight/-/autocomplete_sources/issues?type=WorkItem&work_item_type_id=1',
-      });
-    });
-  });
 });
 
 describe('newWorkItemPath', () => {
