@@ -4,6 +4,6 @@ require 'spec_helper'
 
 RSpec.describe GitlabSchema.types['PackagesProtectionRulePackageType'], feature_category: :package_registry do
   it 'exposes all options' do
-    expect(described_class.values.keys).to match_array(%w[CONAN MAVEN NPM PYPI])
+    expect(described_class.values.keys).to match_array(%w[CONAN GENERIC HELM MAVEN NPM NUGET PYPI])
   end
 end
