@@ -5,10 +5,12 @@ require 'spec_helper'
 RSpec.describe GitlabSchema.types['Subscription'], feature_category: :subscription_management do
   it 'has the expected fields' do
     expected_fields = %i[
-      ci_job_created
+      ci_job_processed
       ci_pipeline_schedule_status_updated
       ci_job_status_updated
+      ci_pipeline_creation_requests_updated
       ci_pipeline_status_updated
+      ci_pipeline_statuses_updated
       issuable_assignees_updated
       issue_crm_contacts_updated
       issuable_title_updated
