@@ -46,7 +46,7 @@ RSpec.describe Gitlab::BackgroundMigration::BackfillArchivedAndTraversalIdsToVul
 
   before do
     [project, other_project].each do |p|
-      create_vulnerability_statistic(project_id: p.id)
+      create_vulnerability_statistic(project: p)
     end
   end
 
@@ -62,9 +62,10 @@ RSpec.describe Gitlab::BackgroundMigration::BackfillArchivedAndTraversalIdsToVul
     end
   end
 
-  def create_vulnerability_statistic(project_id:)
+  def create_vulnerability_statistic(project:)
+    namespace = namespaces.find(project.namespace_id)
     vulnerability_statistics.create!(
-      project_id: project_id,
+      project_id: project.id,
       total: 0,
       critical: 0,
       high: 0,
@@ -74,6 +75,7 @@ RSpec.describe Gitlab::BackgroundMigration::BackfillArchivedAndTraversalIdsToVul
       info: 0,
       letter_grade: 0,
       created_at: Time.current,
+      traversal_ids: namespace.traversal_ids,
       updated_at: Time.current
     )
   end
