@@ -162,6 +162,106 @@ RSpec.describe Gitlab::GithubImport::Representation::DiffNote, feature_category:
         end
       end
 
+      describe '#diff_hunk' do
+        context 'when diff_hunk is nil or empty' do
+          it 'generates a default diff_hunk with default content when merge_request is not available' do
+            note = described_class.new(
+              diff_hunk: nil,
+              file_path: 'README.md',
+              end_line: 15,
+              original_commit_id: 'abc123'
+            )
+
+            expect(note.diff_hunk).to eq("@@ -15,1 +15,1 @@\ncontext not found")
+          end
+
+          it 'generates a default diff_hunk using line attribute when end_line is nil' do
+            note = described_class.new(
+              diff_hunk: nil,
+              file_path: 'README.md',
+              line: 20,
+              end_line: nil,
+              original_commit_id: 'abc123'
+            )
+
+            expect(note.diff_hunk).to eq("@@ -20,1 +20,1 @@\ncontext not found")
+          end
+
+          it 'generates a default diff_hunk with line 1 when both end_line and line are nil' do
+            note = described_class.new(
+              diff_hunk: nil,
+              file_path: 'README.md',
+              original_commit_id: 'abc123'
+            )
+
+            expect(note.diff_hunk).to eq("@@ -1,1 +1,1 @@\ncontext not found")
+          end
+
+          it 'generates a default diff_hunk for empty string' do
+            note = described_class.new(
+              diff_hunk: '',
+              file_path: 'README.md',
+              end_line: 10,
+              original_commit_id: 'abc123'
+            )
+
+            expect(note.diff_hunk).to eq("@@ -10,1 +10,1 @@\ncontext not found")
+          end
+
+          it 'does not override existing diff_hunk' do
+            existing_hunk = "@@ -5,3 +5,3 @@\noriginal content"
+            note = described_class.new(
+              diff_hunk: existing_hunk,
+              file_path: 'README.md',
+              end_line: 10,
+              original_commit_id: 'abc123'
+            )
+
+            expect(note.diff_hunk).to eq(existing_hunk)
+          end
+
+          context 'when merge_request is available with repository' do
+            it 'attempts to fetch actual file content' do
+              note = described_class.new(
+                diff_hunk: nil,
+                file_path: 'README.md',
+                end_line: 2,
+                original_commit_id: 'abc123'
+              )
+
+              file_content = "Line 1\nLine 2\nLine 3\n"
+              blob = double(:blob, data: file_content)
+              repository = double(:repository)
+              allow(repository).to receive(:blob_at).with('abc123', 'README.md').and_return(blob)
+
+              project = double(:project, repository: repository)
+              merge_request = double(:merge_request, project: project)
+              note.merge_request = merge_request
+
+              expect(note.diff_hunk).to eq("@@ -2,1 +2,1 @@\nLine 2")
+            end
+
+            it 'falls back to context line when blob is not found' do
+              note = described_class.new(
+                diff_hunk: nil,
+                file_path: 'README.md',
+                end_line: 2,
+                original_commit_id: 'abc123'
+              )
+
+              repository = double(:repository)
+              allow(repository).to receive(:blob_at).with('abc123', 'README.md').and_return(nil)
+
+              project = double(:project, repository: repository)
+              merge_request = double(:merge_request, project: project)
+              note.merge_request = merge_request
+
+              expect(note.diff_hunk).to eq("@@ -2,1 +2,1 @@\ncontext not found")
+            end
+          end
+        end
+      end
+
       describe '#note and #contains_suggestion?' do
         it 'includes the note body' do
           expect(note.note).to eq('Hello world')
