@@ -67,6 +67,7 @@ RSpec.describe Gitlab::ImportExport::Project::RelationFactory, :use_clean_rails_
         'job_events' => false,
         'wiki_page_events' => true,
         'releases_events' => false,
+        'milestone_events' => false,
         'emoji_events' => false,
         'resource_access_token_events' => false,
         'token' => token
@@ -542,6 +543,23 @@ RSpec.describe Gitlab::ImportExport::Project::RelationFactory, :use_clean_rails_
     end
   end
 
+  describe 'DesignManagement::Version object' do
+    let(:relation_sym) { :design_versions }
+    let(:relation_hash) do
+      {
+        'sha' => SecureRandom.hex(20),
+        'created_at' => Time.now,
+        'author_id' => 1,
+        'actions' => [],
+        'project_id' => project.id
+      }
+    end
+
+    it 'sets the namespace_id based on the project' do
+      expect(created_object.namespace_id).to eq(project.project_namespace.id)
+    end
+  end
+
   describe 'protected refs access levels' do
     shared_examples 'access levels' do
       let(:relation_hash) { { 'access_level' => access_level, 'created_at' => '2022-03-29T09:53:13.457Z', 'updated_at' => '2022-03-29T09:54:13.457Z' } }
@@ -715,4 +733,92 @@ RSpec.describe Gitlab::ImportExport::Project::RelationFactory, :use_clean_rails_
       end
     end
   end
+
+  describe 'MergeRequest::DiffCommitUser' do
+    let(:relation_sym) { :'MergeRequest::DiffCommitUser' }
+    let(:relation_hash) do
+      {
+        'name' => 'Test Author',
+        'email' => 'test@example.com'
+      }
+    end
+
+    it 'creates a DiffCommitUser object' do
+      expect(created_object).to be_a(MergeRequest::DiffCommitUser)
+      expect(created_object.name).to eq('Test Author')
+      expect(created_object.email).to eq('test@example.com')
+    end
+
+    it 'passes project to ObjectBuilder' do
+      expect(Gitlab::ImportExport::Project::ObjectBuilder).to receive(:build).with(
+        MergeRequest::DiffCommitUser,
+        hash_including('project' => project)
+      ).and_call_original
+
+      created_object
+    end
+  end
+
+  describe 'MergeRequestDiffCommit' do
+    let(:relation_sym) { :merge_request_diff_commits }
+    let(:relation_hash) do
+      {
+        'sha' => '123abc',
+        'relative_order' => 1,
+        'message' => 'Test commit',
+        'authored_date' => '2023-01-01',
+        'committed_date' => '2023-01-01',
+        'author_name' => 'Test Author',
+        'author_email' => 'author@example.com',
+        'committer_name' => 'Test Committer',
+        'committer_email' => 'committer@example.com'
+      }
+    end
+
+    it 'creates a MergeRequestDiffCommit object' do
+      expect(created_object).to be_a(MergeRequestDiffCommit)
+      expect(created_object.sha).to eq('123abc')
+    end
+
+    it 'passes project to ObjectBuilder' do
+      expect(Gitlab::ImportExport::Project::ObjectBuilder).to receive(:build).with(
+        MergeRequestDiffCommit,
+        hash_including('project' => project)
+      ).and_call_original
+
+      created_object
+    end
+  end
+
+  describe 'MergeRequest::CommitsMetadata' do
+    let_it_be(:commit_author) { create(:merge_request_diff_commit_user) }
+    let_it_be(:committer) { create(:merge_request_diff_commit_user) }
+
+    let(:relation_sym) { :merge_request_commits_metadata }
+    let(:relation_hash) do
+      {
+        'sha' => '123abc',
+        'message' => 'Test commit',
+        'trailers' => { 'foo' => 'bar' },
+        'authored_date' => '2023-01-01',
+        'committed_date' => '2023-01-01',
+        'commit_author' => commit_author,
+        'committer' => committer
+      }
+    end
+
+    it 'creates a MergeRequest::CommitsMetadata object' do
+      expect(created_object).to be_a(MergeRequest::CommitsMetadata)
+      expect(created_object.sha).to eq('123abc')
+    end
+
+    it 'passes project to ObjectBuilder' do
+      expect(Gitlab::ImportExport::Project::ObjectBuilder).to receive(:build).with(
+        MergeRequest::CommitsMetadata,
+        hash_including('project' => project)
+      ).and_call_original
+
+      created_object
+    end
+  end
 end
