@@ -13,14 +13,7 @@ RSpec.describe QueueBackfillArchivedAndTraversalIdsToVulnerabilityStatistics, mi
       }
 
       migration.after -> {
-        expect(batched_migration).to have_scheduled_batched_migration(
-          gitlab_schema: :gitlab_sec,
-          table_name: :vulnerability_statistics,
-          column_name: :id,
-          interval: described_class::DELAY_INTERVAL,
-          batch_size: described_class::BATCH_SIZE,
-          sub_batch_size: described_class::SUB_BATCH_SIZE
-        )
+        expect(batched_migration).not_to have_scheduled_batched_migration
       }
     end
   end
