@@ -46,13 +46,12 @@ RSpec.describe Ci::Catalog::Resource, feature_category: :pipeline_composition do
 
   it { is_expected.to delegate_method(:avatar_path).to(:project) }
   it { is_expected.to delegate_method(:star_count).to(:project) }
-  it { is_expected.to delegate_method(:archived).to(:project) }
 
   it { is_expected.to define_enum_for(:state).with_values({ unpublished: 0, published: 1 }) }
 
   it 'defines verification levels matching the source of truth in VerifiedNamespace' do
     is_expected.to define_enum_for(:verification_level)
-      .with_values(::Ci::Catalog::VerifiedNamespace::VERIFICATION_LEVELS)
+      .with_values(::Namespaces::VerifiedNamespace::VERIFICATION_LEVELS)
   end
 
   describe '.for_projects' do
@@ -166,7 +165,7 @@ RSpec.describe Ci::Catalog::Resource, feature_category: :pipeline_composition do
   describe '.for_verification_level' do
     it 'returns catalog resources for required verification_level' do
       verified_resources = described_class
-        .for_verification_level(Ci::Catalog::VerifiedNamespace::VERIFICATION_LEVELS[:gitlab_maintained])
+        .for_verification_level(Namespaces::VerifiedNamespace::VERIFICATION_LEVELS[:gitlab_maintained])
 
       expect(verified_resources).to eq([resource_a])
     end
@@ -275,6 +274,34 @@ RSpec.describe Ci::Catalog::Resource, feature_category: :pipeline_composition do
     end
   end
 
+  describe '#archived' do
+    using RSpec::Parameterized::TableSyntax
+
+    let_it_be_with_reload(:root_group) { create(:group) }
+    let_it_be_with_reload(:subgroup) { create(:group, parent: root_group) }
+    let_it_be_with_reload(:project) { create(:project, namespace: subgroup) }
+    let_it_be_with_reload(:resource) { create(:ci_catalog_resource, project: project) }
+
+    where(:project_archived, :subgroup_archived, :root_group_archived, :expected_result) do
+      false | false | false | false
+      true  | false | false | true
+      false | true  | false | true
+      false | false | true  | true
+    end
+
+    with_them do
+      before do
+        project.update!(archived: project_archived)
+        subgroup.update!(archived: subgroup_archived)
+        root_group.update!(archived: root_group_archived)
+      end
+
+      it 'returns the expected archived status' do
+        expect(resource.archived).to eq(expected_result)
+      end
+    end
+  end
+
   describe '#state' do
     it 'defaults to unpublished' do
       expect(resource_a.state).to eq('unpublished')
@@ -354,21 +381,13 @@ RSpec.describe Ci::Catalog::Resource, feature_category: :pipeline_composition do
     let_it_be(:resource) { create(:ci_catalog_resource, project: project) }
 
     let_it_be_with_refind(:january_release) do
-      release = create(:release, :with_catalog_resource_version, project: project, tag: 'v1',
+      create(:release, :with_catalog_resource_version, project: project, tag: '1.0.0',
         released_at: '2023-01-01T00:00:00Z')
-
-      release.catalog_resource_version.update!(semver: '1.0.0')
-
-      release
     end
 
     let_it_be_with_refind(:february_release) do
-      release = create(:release, :with_catalog_resource_version, project: project, tag: 'v2',
+      create(:release, :with_catalog_resource_version, project: project, tag: '2.0.0',
         released_at: '2023-02-01T00:00:00Z')
-
-      release.catalog_resource_version.update!(semver: '2.0.0')
-
-      release
     end
 
     it 'has the expected latest_released_at value' do
@@ -377,11 +396,9 @@ RSpec.describe Ci::Catalog::Resource, feature_category: :pipeline_composition do
 
     context 'when a new catalog resource version is created' do
       it 'updates the latest_released_at value' do
-        march_release = create(:release, :with_catalog_resource_version, project: project, tag: 'v3',
+        march_release = create(:release, :with_catalog_resource_version, project: project, tag: '3.0.0',
           released_at: '2023-03-01T00:00:00Z')
 
-        march_release.catalog_resource_version.update!(semver: '3.0.0')
-
         expect(resource.reload.latest_released_at).to eq(march_release.released_at)
       end
     end
