@@ -359,6 +359,17 @@ RSpec.describe Integrations::GitlabSlackApplication, feature_category: :integrat
       )
     end
 
+    it 'sets the correct sharding key on the newly created integration' do
+      initial_integration.after_build_from_integration(new_integration)
+
+      new_slack_integration = new_integration.slack_integration
+      expect(new_slack_integration).to have_attributes(
+        organization_id: nil,
+        project_id: project.id,
+        group_id: nil
+      )
+    end
+
     context 'when parent integration has no slack_integration' do
       let(:initial_integration) do
         create(:gitlab_slack_application_integration, slack_integration: nil, active: false)
@@ -373,5 +384,42 @@ RSpec.describe Integrations::GitlabSlackApplication, feature_category: :integrat
         expect(new_integration).not_to be_active
       end
     end
+
+    context 'when duplicating to group level' do
+      let(:group) { create(:group) }
+      let(:new_integration) { build(:gitlab_slack_application_integration, group: group) }
+
+      it 'sets the correct sharding key on the newly created integration' do
+        initial_integration.after_build_from_integration(new_integration)
+
+        new_slack_integration = new_integration.slack_integration
+        expect(new_slack_integration).to have_attributes(
+          organization_id: nil,
+          project_id: nil,
+          group_id: group.id
+        )
+      end
+    end
+
+    context 'when duplicating to instance level' do
+      let(:new_integration) { build(:gitlab_slack_application_integration, project: nil) }
+
+      it 'sets alias to instance default' do
+        initial_integration.after_build_from_integration(new_integration)
+
+        expect(new_integration.slack_integration.alias).to eq(SlackIntegration::INSTANCE_ALIAS)
+      end
+
+      it 'sets the correct sharding key on the newly created integration' do
+        initial_integration.after_build_from_integration(new_integration)
+
+        new_slack_integration = new_integration.slack_integration
+        expect(new_slack_integration).to have_attributes(
+          organization_id: new_integration.organization_id,
+          project_id: nil,
+          group_id: nil
+        )
+      end
+    end
   end
 end
