@@ -1173,7 +1173,7 @@ RSpec.describe Member, feature_category: :groups_and_projects do
     end
   end
 
-  describe '.with_group_group_sharing_access' do
+  describe '.shared_members' do
     let_it_be(:shared_group) { create(:group) }
     let_it_be(:invited_group) { create(:group) }
 
@@ -1187,19 +1187,21 @@ RSpec.describe Member, feature_category: :groups_and_projects do
         create(:group_group_link,
           shared_group: shared_group,
           shared_with_group: invited_group,
-          group_access: group_sharing_access)
+          group_access: group_sharing_access
+        )
       end
 
       let(:member) { create(:group_member, source: invited_group, access_level: member_access_in_invited_group) }
 
+      subject(:members) do
+        described_class
+          .shared_members(shared_group)
+          .id_in(member.id)
+          .to_a
+      end
+
       shared_examples 'returns the minimum of member access level and group sharing access level' do
         specify do
-          members = invited_group
-                         .members
-                         .with_group_group_sharing_access(shared_group)
-                         .id_in(member.id)
-                         .to_a
-
           expect(members.size).to eq(1)
           expect(members.first.access_level).to eq(Gitlab::Access::REPORTER)
         end
@@ -1218,6 +1220,16 @@ RSpec.describe Member, feature_category: :groups_and_projects do
     end
   end
 
+  describe '.null_member_role_id_sql' do
+    subject(:null_member_role_id_sql) { described_class.null_member_role_id_sql }
+
+    it 'returns an Arel As node' do
+      expect(null_member_role_id_sql).to be_a(Arel::Nodes::As)
+      expect(null_member_role_id_sql.left.to_s).to eq('NULL')
+      expect(null_member_role_id_sql.right.to_s).to eq('member_role_id')
+    end
+  end
+
   describe '#accept_request', :freeze_time do
     let(:member) { create(:project_member, requested_at: Time.current.utc) }
     let(:current_time) { Time.current.utc }
@@ -1828,33 +1840,19 @@ RSpec.describe Member, feature_category: :groups_and_projects do
         end
 
         it 'checks for member owned pipeline_schedules' do
-          stub_feature_flags(notify_pipeline_schedule_owner_unavailable: true)
-
           expect(member).to receive(:notify_unavailable_owned_pipeline_schedules)
             .with(member.user.id, member.source)
 
           member.update_attribute(:access_level, Member::REPORTER)
         end
-
-        context 'when feature flag disabled' do
-          before do
-            stub_feature_flags(notify_pipeline_schedule_owner_unavailable: false)
-          end
-
-          it 'does not check for member owned pipeline_schedules when feature flag disabled' do
-            expect(member).not_to receive(:notify_unavailable_owned_pipeline_schedules)
-
-            member.update_attribute(:access_level, Member::REPORTER)
-          end
-        end
       end
     end
 
     context 'when expiration is changed' do
-      it 'calls the notification service when membership expiry has changed' do
-        expect(NotificationService).to receive_message_chain(:new, :updated_member_expiration).with(member)
-
-        member.update!(expires_at: 5.days.from_now)
+      it 'enqueues the expiration date updated mailer when membership expiry has changed' do
+        expect { member.update!(expires_at: 5.days.from_now) }
+          .to have_enqueued_mail(Members::ExpirationDateUpdatedMailer, :email)
+          .with(params: { member: member, member_source_type: member.real_source_type }, args: [])
       end
     end
   end
@@ -2010,25 +2008,11 @@ RSpec.describe Member, feature_category: :groups_and_projects do
     end
 
     it 'checks for member owned pipeline_schedules' do
-      stub_feature_flags(notify_pipeline_schedule_owner_unavailable: true)
-
       expect(member).to receive(:notify_unavailable_owned_pipeline_schedules)
         .with(member.user.id, member.source)
 
       member.destroy!
     end
-
-    context 'when feature flag disabled' do
-      before do
-        stub_feature_flags(notify_pipeline_schedule_owner_unavailable: false)
-      end
-
-      it 'does not check for member owned pipeline_schedules when feature flag disabled' do
-        expect(member).not_to receive(:notify_unavailable_owned_pipeline_schedules)
-
-        member.destroy!
-      end
-    end
   end
 
   describe 'log_invitation_token_cleanup' do
