@@ -11,7 +11,23 @@ RSpec.describe MergeRequests::GeneratedRefCommit, feature_category: :code_review
   end
 
   describe 'associations' do
-    it { is_expected.to belong_to(:merge_request) }
+    if ::Gitlab.next_rails?
+      it 'belongs to merge_request' do
+        is_expected.to belong_to(:merge_request)
+          .with_primary_key(%i[iid target_project_id])
+          .with_query_constraints(%i[merge_request_iid project_id])
+          .inverse_of(:generated_ref_commits)
+      end
+    else
+      it 'belongs to merge_request' do
+        is_expected.to belong_to(:merge_request)
+          .with_primary_key(%i[iid target_project_id])
+          .with_foreign_key(:merge_request_iid)
+          .inverse_of(:generated_ref_commits)
+          .with_query_constraints(%i[merge_request_iid project_id])
+      end
+    end
+
     it { is_expected.to belong_to(:project) }
   end
 
