@@ -1,7 +1,8 @@
 # frozen_string_literal: true
+
 require 'spec_helper'
 
-RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_registry do
+RSpec.describe Packages::PackageFile, feature_category: :package_registry do
   using RSpec::Parameterized::TableSyntax
 
   let_it_be(:project) { create(:project) }
@@ -19,8 +20,16 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
     it { is_expected.to belong_to(:package) }
     it { is_expected.to have_one(:conan_file_metadatum) }
     it { is_expected.to have_many(:package_file_build_infos).inverse_of(:package_file) }
-    it { is_expected.to have_one(:debian_file_metadatum).inverse_of(:package_file).class_name('Packages::Debian::FileMetadatum') }
-    it { is_expected.to have_one(:helm_file_metadatum).inverse_of(:package_file).class_name('Packages::Helm::FileMetadatum') }
+
+    it 'has one debian file metadatum' do
+      is_expected.to have_one(:debian_file_metadatum).inverse_of(:package_file)
+        .class_name('Packages::Debian::FileMetadatum')
+    end
+
+    it 'has one helm file metadatum' do
+      is_expected.to have_one(:helm_file_metadatum).inverse_of(:package_file)
+        .class_name('Packages::Helm::FileMetadatum')
+    end
   end
 
   describe 'included modules' do
@@ -37,34 +46,34 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
       let(:status) { :default }
       let(:file_name) { 'foo' }
       let(:file) { fixture_file_upload('spec/fixtures/dk.png') }
-      let(:params) { { file: file, file_name: file_name, status: status } }
+      let(:params) { { file:, file_name:, status: } }
+      let(:new_package_file) { build(:package_file, package:, **params) }
 
-      subject { package.package_files.create!(params) }
-
-      context 'file_name' do
+      context 'for file_name' do
         let(:file_name) { package_file.file_name }
 
         it 'can not save a duplicated file' do
-          expect { subject }.to raise_error(ActiveRecord::RecordInvalid, "Validation failed: File name has already been taken")
+          expect(new_package_file).to be_invalid
+            .and have_attributes(errors: match_array(['File name has already been taken']))
         end
 
         context 'with a pending destruction package duplicated file' do
           let(:status) { :pending_destruction }
 
           it 'can save it' do
-            expect { subject }.to change { package.package_files.count }.from(1).to(2)
+            expect { new_package_file.save! }.to change { package.package_files.count }.from(1).to(2)
           end
         end
       end
 
-      context 'file_sha256' do
+      context 'for file_sha256' do
         where(:sha256_value, :expected_success) do
-          ('a' * 64) | true
-          nil | true
-          ('a' * 63)       | false
-          ('a' * 65)       | false
-          (('a' * 63) + '%') | false
-          '' | false
+          ('a' * 64)     | true
+          nil            | true
+          ('a' * 63)     | false
+          ('a' * 65)     | false
+          "#{'a' * 63}%" | false
+          ''             | false
         end
 
         with_them do
@@ -72,14 +81,102 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
 
           it 'does not allow invalid sha256 characters' do
             if expected_success
-              expect { subject }.not_to raise_error
+              expect(new_package_file).to be_valid
             else
-              expect { subject }.to raise_error(ActiveRecord::RecordInvalid, "Validation failed: File sha256 is invalid")
+              expect(new_package_file).to be_invalid
+                .and have_attributes(errors: match_array(['File sha256 is invalid']))
             end
           end
         end
       end
     end
+
+    context 'with conan package' do
+      let_it_be(:package) { create(:conan_package, without_package_files: true) }
+      let_it_be(:recipe_revision) { package.conan_recipe_revisions.first }
+      let_it_be(:package_reference) { package.conan_package_references.first }
+      let_it_be(:package_revision) { package.conan_package_revisions.first }
+
+      let!(:existing_file) do
+        create(:conan_package_file, :conan_package, package: package, conan_recipe_revision: recipe_revision,
+          conan_package_revision: package_revision)
+      end
+
+      context 'when creating a new file' do
+        let(:new_file) do
+          build(
+            :conan_package_file,
+            :conan_package,
+            package: package,
+            file_name: 'conan_package.tgz',
+            conan_file_metadatum: build(
+              :conan_file_metadatum,
+              :package_file,
+              recipe_revision: recipe_revision,
+              package_reference: package_reference,
+              package_revision: package_revision
+            )
+          )
+        end
+
+        it 'validates uniqueness of file name with same recipe revision, package reference and package revision' do
+          expect(new_file).not_to be_valid
+          expect(new_file.errors[:file_name]).to include(
+            'already exists for the given recipe revision, package reference, and package revision'
+          )
+        end
+
+        it 'allows same file name with different recipe revision' do
+          new_file.conan_file_metadatum.recipe_revision = build_stubbed(:conan_recipe_revision, package: package)
+          expect(new_file).to be_valid
+        end
+
+        it 'allows same file name with different package reference' do
+          new_file.conan_file_metadatum.package_reference = build_stubbed(:conan_package_reference, package: package)
+          expect(new_file).to be_valid
+        end
+
+        it 'allows same file name with different package revision' do
+          new_file.conan_file_metadatum.package_revision = build_stubbed(:conan_package_revision, package: package)
+          expect(new_file).to be_valid
+        end
+
+        it 'allows same file name without revision' do
+          new_file.conan_file_metadatum.recipe_revision = nil
+          new_file.conan_file_metadatum.package_revision = nil
+          expect(new_file).to be_valid
+        end
+
+        context 'when existing file is not installable' do
+          it 'allows same file name' do
+            existing_file.pending_destruction!
+            expect(new_file).to be_valid
+          end
+        end
+
+        context 'when both existing and new files have no revision' do
+          let_it_be(:recipe_revision) { nil }
+          let_it_be(:package_revision) { nil }
+
+          it 'allows same file name' do
+            expect(new_file).to be_valid
+          end
+        end
+
+        context 'when updating an existing file' do
+          it 'does not validate uniqueness on update' do
+            duplicate_file = create(
+              :conan_package_file,
+              :conan_package,
+              package: package,
+              file_name: 'duplicate_conan_package.tgz'
+            )
+
+            expect { existing_file.update!(file_name: duplicate_file.file_name) }.not_to raise_error
+          end
+        end
+      end
+    end
   end
 
   context 'with package filenames' do
@@ -112,7 +209,7 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
     end
   end
 
-  context 'updating project statistics' do
+  context 'for updating project statistics' do
     let_it_be(:package, reload: true) { create(:maven_package, package_files: [], maven_metadatum: nil) }
 
     context 'when the package file has an explicit size' do
@@ -143,7 +240,7 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
     end
   end
 
-  context 'Conan scopes' do
+  context 'for Conan scopes' do
     let_it_be(:package) { create(:conan_package, without_package_files: true) }
 
     describe '.with_conan_package_reference' do
@@ -162,13 +259,13 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
           conan_package_reference: other_package_reference)
       end
 
-      subject { described_class.with_conan_package_reference(reference) }
+      subject(:result) { described_class.with_conan_package_reference(reference) }
 
       context 'with existing reference' do
         let(:reference) { matching_package_file.conan_file_metadatum.package_reference.reference }
 
         it 'returns package files with matching reference' do
-          expect(subject).to contain_exactly(matching_package_file)
+          expect(result).to contain_exactly(matching_package_file)
         end
       end
 
@@ -176,12 +273,12 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
         let(:reference) { non_existing_record_id.to_s }
 
         it 'returns empty relation' do
-          expect(subject).to be_empty
+          expect(result).to be_empty
         end
       end
     end
 
-    context 'recipe revision scopes' do
+    context 'for recipe revision scopes' do
       let_it_be(:recipe_revision) { package.conan_recipe_revisions.first }
       let_it_be(:other_revision) { create(:conan_recipe_revision, package: package) }
 
@@ -203,13 +300,13 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
       end
 
       describe '.with_conan_recipe_revision' do
-        subject { described_class.with_conan_recipe_revision(revision) }
+        subject(:result) { described_class.with_conan_recipe_revision(revision) }
 
         context 'with existing revision' do
           let(:revision) { recipe_revision.revision }
 
           it 'returns package files with matching recipe revision' do
-            expect(subject).to contain_exactly(package_file_with_revision)
+            expect(result).to contain_exactly(package_file_with_revision)
           end
         end
 
@@ -217,22 +314,74 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
           let(:revision) { 'nonexistent' }
 
           it 'returns empty relation' do
-            expect(subject).to be_empty
+            expect(result).to be_empty
           end
         end
       end
 
       describe '.without_conan_recipe_revision' do
-        subject { described_class.without_conan_recipe_revision }
+        subject(:result) { described_class.without_conan_recipe_revision }
 
         it 'returns only package files without recipe revision' do
-          expect(subject).to contain_exactly(package_file_without_revision)
+          expect(result).to contain_exactly(package_file_without_revision)
+        end
+      end
+    end
+
+    context 'for package revision scopes' do
+      let_it_be(:package_revision) { package.conan_package_revisions.first }
+      let_it_be(:other_package_revision) do
+        create(:conan_package_revision, package_reference: package.conan_package_references.first)
+      end
+
+      let_it_be(:package_file_with_revision) do
+        create(:conan_package_file, :conan_package,
+          package: package,
+          conan_package_revision: package_revision)
+      end
+
+      let_it_be(:package_file_with_other_revision) do
+        create(:conan_package_file, :conan_package,
+          package: package,
+          conan_package_revision: other_package_revision)
+      end
+
+      let_it_be(:package_file_without_revision) do
+        create(:conan_package_file, :conan_package,
+          package: package, conan_recipe_revision: nil, conan_package_revision: nil)
+      end
+
+      describe '.with_conan_package_revision' do
+        subject(:result) { described_class.with_conan_package_revision(revision) }
+
+        context 'with existing revision' do
+          let(:revision) { package_revision.revision }
+
+          it 'returns package files with matching package revision' do
+            expect(result).to contain_exactly(package_file_with_revision)
+          end
+        end
+
+        context 'when revision does not exist' do
+          let(:revision) { 'nonexistent' }
+
+          it 'returns empty relation' do
+            expect(result).to be_empty
+          end
+        end
+      end
+
+      describe '.without_conan_package_revision' do
+        subject(:result) { described_class.without_conan_package_revision }
+
+        it 'returns only package files without package revision' do
+          expect(result).to contain_exactly(package_file_without_revision)
         end
       end
     end
   end
 
-  context 'Debian scopes' do
+  context 'for Debian scopes' do
     let_it_be(:debian_changes) { debian_package.package_files.last }
     let_it_be(:debian_deb) { create(:debian_package_file, package: debian_package) }
     let_it_be(:debian_udeb) { create(:debian_package_file, :udeb, package: debian_package) }
@@ -270,7 +419,9 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
         incoming.package_files.second.update! updated_at: 1.day.ago, status: :error
       end
 
-      it { expect(described_class.with_debian_unknown_since(1.hour.ago)).to contain_exactly(incoming.package_files.first) }
+      it 'returns package files with updated_at older than 1 hour' do
+        expect(described_class.with_debian_unknown_since(1.hour.ago)).to contain_exactly(incoming.package_files.first)
+      end
     end
   end
 
@@ -290,7 +441,9 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
     end
 
     context 'with package files pending destruction' do
-      let_it_be(:package_file_pending_destruction) { create(:helm_package_file, :pending_destruction, package: helm_package2, channel: channel) }
+      let_it_be(:package_file_pending_destruction) do
+        create(:helm_package_file, :pending_destruction, package: helm_package2, channel: channel)
+      end
 
       it 'does not return them' do
         expect(described_class.for_helm_with_channel(project, channel)).to contain_exactly(helm_file2)
@@ -317,7 +470,7 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
     let_it_be(:package_file4_2) { create(:package_file, :npm, package: package2) }
     let_it_be(:package_file4_3) { create(:package_file, :npm, package: package2) }
     let_it_be(:package_file4_4) { create(:package_file, :npm, package: package2) }
-    let_it_be(:package_file4_4) { create(:package_file, :npm, :pending_destruction, package: package2) }
+    let_it_be(:package_file4_5) { create(:package_file, :npm, :pending_destruction, package: package2) }
 
     let(:most_recent_package_file1) { package1.installable_package_files.recent.first }
     let(:most_recent_package_file2) { package2.installable_package_files.recent.first }
@@ -337,17 +490,50 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
       let(:compact_inputs) { [package_input1, package_input2, package_input3, package_input4].compact }
       let(:packages) do
         ::Packages::Package.id_in(
-          compact_inputs.map { |pkg_number| public_send("package#{pkg_number}") }
+          compact_inputs.map { |pkg_number| public_send(:"package#{pkg_number}") }
             .map(&:id)
         )
       end
 
-      let(:expected_package_files) { compact_inputs.map { |pkg_number| public_send("most_recent_package_file#{pkg_number}") } }
+      let(:expected_package_files) do
+        compact_inputs.map do |pkg_number|
+          public_send(:"most_recent_package_file#{pkg_number}")
+        end
+      end
 
-      it { is_expected.to contain_exactly(*expected_package_files) }
+      it { is_expected.to match_array(expected_package_files) }
     end
 
-    context 'extra join and extra where' do
+    describe '.order_by' do
+      let_it_be(:package) { create(:generic_package, project:) }
+      let_it_be(:older_file) { create(:package_file, package: package, file_name: 'beta.txt', created_at: 2.days.ago) }
+      let_it_be(:newer_file) { create(:package_file, package: package, file_name: 'alpha.txt', created_at: 1.day.ago) }
+
+      where(:column_name, :order, :expected_order) do
+        'id'         | 'asc'     | ->(older, newer) { [older, newer] }
+        'id'         | 'desc'    | ->(older, newer) { [newer, older] }
+        'file_name'  | 'asc'     | ->(older, newer) { [newer, older] }
+        'file_name'  | 'desc'    | ->(older, newer) { [older, newer] }
+        'created_at' | 'asc'     | ->(older, newer) { [older, newer] }
+        'created_at' | 'desc'    | ->(older, newer) { [newer, older] }
+        'invalid'    | 'asc'     | nil
+        'id'         | 'invalid' | nil
+      end
+
+      with_them do
+        subject(:ordered_files) { described_class.where(package:).order_by(column_name, order) }
+
+        it 'returns the package files in the expected order' do
+          if expected_order
+            expect(ordered_files.first(2)).to eq(expected_order.call(older_file, newer_file))
+          else
+            expect(ordered_files.order_values).to be_empty
+          end
+        end
+      end
+    end
+
+    context 'for extra join and extra where' do
       let_it_be(:helm_package) { create(:helm_package, without_package_files: true) }
       let_it_be(:helm_package_file1) { create(:helm_package_file, channel: 'alpha') }
       let_it_be(:helm_package_file2) { create(:helm_package_file, channel: 'alpha', package: helm_package) }
@@ -357,17 +543,22 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
       let(:extra_join) { :helm_file_metadatum }
       let(:extra_where) { { packages_helm_file_metadata: { channel: 'alpha' } } }
 
-      subject { described_class.most_recent_for(Packages::Package.id_in(helm_package.id), extra_join: extra_join, extra_where: extra_where) }
+      subject(:joined_result) do
+        described_class.most_recent_for(Packages::Package.id_in(helm_package.id), extra_join: extra_join,
+          extra_where: extra_where)
+      end
 
       it 'returns the most recent package for the selected channel' do
-        expect(subject).to contain_exactly(helm_package_file2)
+        expect(joined_result).to contain_exactly(helm_package_file2)
       end
 
       context 'with package files pending destruction' do
-        let_it_be(:package_file_pending_destruction) { create(:helm_package_file, :pending_destruction, package: helm_package, channel: 'alpha') }
+        let_it_be(:package_file_pending_destruction) do
+          create(:helm_package_file, :pending_destruction, package: helm_package, channel: 'alpha')
+        end
 
         it 'does not return them' do
-          expect(subject).to contain_exactly(helm_package_file2)
+          expect(joined_result).to contain_exactly(helm_package_file2)
         end
       end
     end
@@ -378,11 +569,11 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
 
     subject { package_file.pipelines }
 
-    context 'package_file without pipeline' do
+    context 'for package_file without pipeline' do
       it { is_expected.to be_empty }
     end
 
-    context 'package_file with pipeline' do
+    context 'for package_file with pipeline' do
       let_it_be(:pipeline) { create(:ci_pipeline) }
       let_it_be(:pipeline2) { create(:ci_pipeline) }
 
@@ -398,26 +589,26 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
   describe '#update_file_store callback' do
     let_it_be(:package_file) { build(:package_file, :nuget, size: nil) }
 
-    subject { package_file.save! }
+    subject(:save_result) { package_file.save! }
 
     it 'updates metadata columns' do
       expect(package_file)
         .to receive(:update_file_store)
         .and_call_original
 
-      expect { subject }.to change { package_file.size }.from(nil).to(3513)
+      expect { save_result }.to change { package_file.size }.from(nil).to(3513)
     end
   end
 
-  context 'update callbacks' do
-    subject { package_file.save! }
+  context 'for update callbacks' do
+    subject(:save_result) { package_file.save! }
 
     shared_examples 'executing the default callback' do
       it 'executes the default callback' do
         expect(package_file).to receive(:remove_previously_stored_file)
         expect(package_file).not_to receive(:move_in_object_storage)
 
-        subject
+        save_result
       end
     end
 
@@ -470,13 +661,13 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
           expect(package_file.file.file).to receive(:copy_to).and_call_original
           expect(package_file.file.file).to receive(:delete).and_call_original
 
-          subject
+          save_result
         end
       end
     end
   end
 
-  context 'status scopes' do
+  context 'for status scopes' do
     let_it_be(:package) { create(:generic_package) }
     let_it_be(:default_package_file) { create(:package_file, package: package) }
     let_it_be(:pending_destruction_package_file) { create(:package_file, :pending_destruction, package: package) }
@@ -518,4 +709,66 @@ RSpec.describe Packages::PackageFile, type: :model, feature_category: :package_r
       end
     end
   end
+
+  it_behaves_like 'object storable' do
+    let(:locally_stored) do
+      package_file = create(:package_file)
+
+      if package_file.file_store == ObjectStorage::Store::REMOTE
+        package_file.update_column(described_class::STORE_COLUMN, ObjectStorage::Store::LOCAL)
+      end
+
+      package_file
+    end
+
+    let(:remotely_stored) do
+      package_file = create(:package_file)
+
+      if package_file.file_store == ObjectStorage::Store::LOCAL
+        package_file.update_column(described_class::STORE_COLUMN, ObjectStorage::Store::REMOTE)
+      end
+
+      package_file
+    end
+  end
+
+  describe '.for_projects' do
+    let_it_be(:package) { create(:generic_package) }
+    let_it_be(:package2) { create(:generic_package) }
+    let_it_be(:package_file1) { create(:package_file, package: package) }
+    let_it_be(:package_file2) { create(:package_file, package: package2) }
+    let_it_be(:package_file3) { create(:package_file) }
+
+    let(:projects) { ::Project.id_in([package_file1.project_id, package_file2.project_id]) }
+
+    subject { described_class.for_projects(projects.select(:id)) }
+
+    it { is_expected.to contain_exactly(package_file1, package_file2) }
+
+    context 'with projects' do
+      subject { described_class.for_projects(projects) }
+
+      it { is_expected.to contain_exactly(package_file1, package_file2) }
+    end
+  end
+
+  describe '.preload_pipelines_with_user_project_namespace_route' do
+    let_it_be(:project) { create(:project) }
+    let_it_be(:package) { create(:generic_package, project: project) }
+    let_it_be(:pipeline) { create(:ci_pipeline, project: package.project) }
+    let_it_be(:package_file) { create(:package_file, pipelines: [pipeline], package: package) }
+
+    subject(:execute) { described_class.preload_pipelines_with_user_project_namespace_route.id_in(package_file.id) }
+
+    it 'preloads pipelines with user, project, namespace and route' do
+      record = execute.first
+      pipeline = record.pipelines.first
+
+      expect(record.association(:pipelines)).to be_loaded
+      expect(pipeline.association(:user)).to be_loaded
+      expect(pipeline.association(:project)).to be_loaded
+      expect(pipeline.project.association(:namespace)).to be_loaded
+      expect(pipeline.project.namespace.association(:route)).to be_loaded
+    end
+  end
 end
