@@ -110,7 +110,7 @@ RSpec.describe Packages::Package, feature_category: :package_registry do
     it { is_expected.to validate_presence_of(:project) }
     it { is_expected.to validate_uniqueness_of(:name).scoped_to(:project_id, :version, :package_type) }
 
-    Packages::Package.package_types.keys.without('conan').each do |pt|
+    Packages::Package.package_types.keys.without('conan', 'composer').each do |pt|
       context "for project id, name, version and package type uniqueness for package type #{pt}" do
         let(:package) { create("#{pt}_package") }
 
@@ -130,6 +130,31 @@ RSpec.describe Packages::Package, feature_category: :package_registry do
         end
       end
     end
+
+    context 'when composer' do
+      context 'for project id, name, version and package type uniqueness for package composer type' do
+        let_it_be_with_reload(:package) { create(:composer_package_sti) }
+
+        let_it_be(:new_package) do
+          build(:composer_package_sti, project: package.project, name: package.name, version: package.version)
+        end
+
+        it 'does not allow a composer package with same project, name, version and package_type' do
+          expect(new_package).not_to be_valid
+          expect(new_package.errors.to_a).to include('Name has already been taken')
+        end
+
+        context 'with pending_destruction package' do
+          before_all do
+            package.pending_destruction!
+          end
+
+          it 'allows a composer package with same project, name, version and package_type' do
+            expect(new_package).to be_valid
+          end
+        end
+      end
+    end
   end
 
   describe '#destroy' do
@@ -162,16 +187,6 @@ RSpec.describe Packages::Package, feature_category: :package_registry do
     end
   end
 
-  describe '.with_package_type' do
-    let!(:package1) { create(:terraform_module_package) }
-    let!(:package2) { create(:npm_package) }
-    let(:package_type) { :terraform_module }
-
-    subject { described_class.with_package_type(package_type) }
-
-    it { is_expected.to eq([package1]) }
-  end
-
   describe '.without_package_type' do
     let!(:package1) { create(:npm_package) }
     let!(:package2) { create(:terraform_module_package) }
@@ -417,6 +432,17 @@ RSpec.describe Packages::Package, feature_category: :package_registry do
     end
   end
 
+  describe '.preload_project' do
+    let_it_be(:project) { create(:project) }
+    let_it_be(:package) { create_list(:npm_package, 2, project: project) }
+
+    subject(:packages) { described_class.preload_project }
+
+    it 'preloads project' do
+      expect(packages.first.association(:project)).to be_loaded
+    end
+  end
+
   describe '.preload_pipelines_with_user_project_namespace_route' do
     let_it_be(:project) { create(:project) }
 
@@ -685,6 +711,7 @@ RSpec.describe Packages::Package, feature_category: :package_registry do
     described_class
       .package_types
       .keys
+      .without('composer')
       .map(&:to_sym)
       .each do |package_format|
       if described_class.inheritance_column_to_class_map[package_format].nil?
@@ -705,6 +732,14 @@ RSpec.describe Packages::Package, feature_category: :package_registry do
         end
       end
     end
+
+    context 'when composer' do
+      let(:package) { create(:composer_package_sti, project: project) }
+
+      it 'maps to the correct class' do
+        is_expected.to eq(Packages::Composer::Sti::Package)
+      end
+    end
   end
 
   describe '#detailed_info?' do
