@@ -17,14 +17,6 @@ RSpec.describe ResourceEvents::AbuseReportEvent, feature_category: :instance_res
     it { is_expected.to be_valid }
     it { is_expected.to validate_presence_of(:action) }
     it { is_expected.to validate_presence_of(:organization_id).on(:create) }
-
-    context 'when abuse_report_populate_organization FF is disabled' do
-      before do
-        stub_feature_flags(abuse_report_populate_organization: false)
-      end
-
-      it { is_expected.not_to validate_presence_of(:organization_id).on(:create) }
-    end
   end
 
   describe '#success_message' do
