@@ -169,6 +169,12 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
           expect(json_response.map { |u| u['id'] }).to match_array [maintainer.id, developer.id]
         end
       end
+
+      it_behaves_like 'authorizing granular token permissions', :read_member do
+        let(:user) { maintainer }
+        let(:boundary_object) { source }
+        let(:request) { get api(members_url, personal_access_token: pat) }
+      end
     end
 
     it_behaves_like 'GET /:source_type/:id/members/(all)', 'project', false do
@@ -187,6 +193,20 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
       let(:source) { group }
     end
 
+    it_behaves_like 'rate limited endpoint', rate_limit_key: :project_members_api do
+      let_it_be(:user2) { create(:user) }
+
+      let(:current_user) { developer }
+
+      def request
+        get api("/projects/#{nested_project.id}/members/all", current_user)
+      end
+
+      def request_with_second_scope
+        get api("/projects/#{nested_project.id}/members/all", user2)
+      end
+    end
+
     context 'when invited groups have public visibility' do
       it 'finds all project members including inherited members and members shared into ancestor groups' do
         get api("/projects/#{nested_project.id}/members/all", developer)
@@ -383,6 +403,12 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
             include_examples 'response with correct access levels'
           end
         end
+
+        it_behaves_like 'authorizing granular token permissions', :read_member do
+          let(:user) { maintainer }
+          let(:boundary_object) { source }
+          let(:request) { get api(members_url, personal_access_token: pat) }
+        end
       end
     end
 
@@ -553,14 +579,10 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
             end.to change { source.members.count }.by(-1)
           end
 
-          it_behaves_like 'rate limited endpoint', rate_limit_key: :members_delete do
+          it_behaves_like 'rate limited endpoint', rate_limit_key: :members_delete, use_second_scope: false do
             let(:current_user) { maintainer }
 
-            let(:another_member) { create(:user) }
-
-            before do
-              source.add_developer(another_member)
-            end
+            let(:another_member) { create(:user, developer_of: source) }
 
             # We rate limit scoped by the group / project
             let(:delete_paths) do
@@ -580,6 +602,14 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
           it_behaves_like '412 response' do
             let(:request) { api("/#{source_type.pluralize}/#{source.id}/members/#{developer.id}", maintainer) }
           end
+
+          it_behaves_like 'authorizing granular token permissions', :delete_member do
+            let(:user) { maintainer }
+            let(:boundary_object) { source }
+            let(:request) do
+              delete api("/#{source_type.pluralize}/#{source.id}/members/#{developer.id}", personal_access_token: pat)
+            end
+          end
         end
 
         it 'returns 404 if member does not exist' do
@@ -633,6 +663,15 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
           end
         end
 
+        it_behaves_like 'authorizing granular token permissions', :create_member do
+          let(:user) { maintainer }
+          let(:boundary_object) { source }
+          let(:request) do
+            post api("/#{source_type.pluralize}/#{source.id}/members", personal_access_token: pat),
+              params: { user_id: stranger.id, access_level: Member::DEVELOPER }
+          end
+        end
+
         context 'when authenticated as a non-member or member with insufficient membership management rights' do
           context 'when the user does not have rights to manage members' do
             %i[access_requester stranger developer].each do |type|
@@ -1118,6 +1157,15 @@ RSpec.describe API::Members, feature_category: :groups_and_projects do
 
           expect(response).to have_gitlab_http_status(:bad_request)
         end
+
+        it_behaves_like 'authorizing granular token permissions', :update_member do
+          let(:user) { maintainer }
+          let(:boundary_object) { source }
+          let(:request) do
+            put api("/#{source_type.pluralize}/#{source.id}/members/#{developer.id}", personal_access_token: pat),
+              params: { access_level: Member::MAINTAINER }
+          end
+        end
       end
     end
 
