@@ -14,7 +14,7 @@ RSpec.describe Groups::UsageQuotasController, :with_license, feature_category: :
   end
 
   describe 'GET /groups/*group_id/-/usage_quotas' do
-    context 'when user has read_usage_quotas permission' do
+    context 'when user has read_usage_quotas permission', :with_trial_types do
       before do
         group.add_owner(user)
       end
@@ -24,7 +24,6 @@ RSpec.describe Groups::UsageQuotasController, :with_license, feature_category: :
 
         expect(response).to have_gitlab_http_status(:ok)
         expect(response.body).to match(/js-usage-quotas-view/)
-          .and have_pushed_frontend_feature_flags(virtualRegistryMaven: true)
       end
 
       it 'renders 404 page if subgroup' do
