@@ -12,53 +12,53 @@ require 'spec_helper'
 # user_calendar              GET    /users/:username/calendar(.:format)
 # user_calendar_activities   GET    /users/:username/calendar_activities(.:format)
 RSpec.describe UsersController, "routing" do
-  it "to #show" do
+  specify "to #show" do
     allow_any_instance_of(::Constraints::UserUrlConstrainer).to receive(:matches?).and_return(true)
 
     expect(get("/User")).to route_to('users#show', username: 'User')
   end
 
-  it "to #gpg_keys" do
+  specify "to #gpg_keys" do
     allow_any_instance_of(::Constraints::UserUrlConstrainer).to receive(:matches?).and_return(true)
 
     expect(get("/User.gpg")).to route_to('users#gpg_keys', username: 'User')
   end
 
-  it "to #groups" do
+  specify "to #groups" do
     expect(get("/users/User/groups")).to route_to('users#groups', username: 'User')
   end
 
-  it "to #projects" do
+  specify "to #projects" do
     expect(get("/users/User/projects")).to route_to('users#projects', username: 'User')
   end
 
-  it "to #contributed" do
+  specify "to #contributed" do
     expect(get("/users/User/contributed")).to route_to('users#contributed', username: 'User')
   end
 
-  it "to #snippets" do
+  specify "to #snippets" do
     expect(get("/users/User/snippets")).to route_to('users#snippets', username: 'User')
   end
 
   # get all the ssh-keys of a user
-  it "to #ssh_keys" do
+  specify "to #ssh_keys" do
     allow_any_instance_of(::Constraints::UserUrlConstrainer).to receive(:matches?).and_return(true)
 
     expect(get("/User.keys")).to route_to('users#ssh_keys', username: 'User')
   end
 
-  it "to #calendar" do
+  specify "to #calendar" do
     expect(get("/users/User/calendar")).to route_to('users#calendar', username: 'User')
   end
 
-  it "to #calendar_activities" do
+  specify "to #calendar_activities" do
     expect(get("/users/User/calendar_activities")).to route_to('users#calendar_activities', username: 'User')
   end
 end
 
 # search GET    /search(.:format) search#show
 RSpec.describe SearchController, "routing" do
-  it "to #show" do
+  specify "to #show" do
     expect(get("/search")).to route_to('search#show')
   end
 end
@@ -66,7 +66,7 @@ end
 # gitlab_api /api         API::API
 #            /:path       Grack
 RSpec.describe "Mounted Apps", "routing" do
-  it "to API" do
+  specify "to API" do
     expect(get("/api/issues")).to be_routable
   end
 end
@@ -76,27 +76,27 @@ end
 # edit_snippet GET    /snippets/:id/edit(.:format) snippets#edit
 #      snippet GET    /snippets/:id(.:format)      snippets#show
 RSpec.describe SnippetsController, "routing" do
-  it "to #raw" do
+  specify "to #raw" do
     expect(get("/-/snippets/1/raw")).to route_to('snippets#raw', id: '1')
   end
 
-  it "to #index" do
+  specify "to #index" do
     expect(get("/-/snippets")).to route_to('snippets#index')
   end
 
-  it "to #new" do
+  specify "to #new" do
     expect(get("/-/snippets/new")).to route_to('snippets#new')
   end
 
-  it "to #edit" do
+  specify "to #edit" do
     expect(get("/-/snippets/1/edit")).to route_to('snippets#edit', id: '1')
   end
 
-  it "to #show" do
+  specify "to #show" do
     expect(get("/-/snippets/1")).to route_to('snippets#show', id: '1')
   end
 
-  it 'to #raw from unscoped routing' do
+  specify 'to #raw from unscoped routing' do
     expect(get("/snippets/1/raw")).to route_to('snippets#raw', id: '1')
   end
 
@@ -107,11 +107,11 @@ end
 #       help_page GET /help/*path(.:format)           help#show
 #  help_shortcuts GET /help/shortcuts(.:format)       help#shortcuts
 RSpec.describe HelpController, "routing" do
-  it "to #index" do
+  specify "to #index" do
     expect(get("/help")).to route_to('help#index')
   end
 
-  it 'to #show' do
+  specify 'to #show' do
     path = '/help/user/markdown.md'
     expect(get(path)).to route_to('help#show', path: 'user/markdown', format: 'md')
 
@@ -127,19 +127,19 @@ end
 #       user_settings_profile PUT    /-/user_settings/profile(.:format)       user_settings/profile#update
 #       user_settings_profile PATCH  /-/user_settings/profile(.:format)       user_settings/profile#update
 RSpec.describe ProfilesController, "routing" do
-  it "to #account" do
+  specify "to #account" do
     expect(get("/-/profile/account")).to route_to('profiles/accounts#show')
   end
 
-  it "to #reset_feed_token" do
+  specify "to #reset_feed_token" do
     expect(put("/-/profile/reset_feed_token")).to route_to('profiles#reset_feed_token')
   end
 
-  it "to #show" do
+  specify "to #show" do
     expect(get("/-/user_settings/profile")).to route_to('user_settings/profiles#show')
   end
 
-  it "to #update" do
+  specify "to #update" do
     expect(put("/-/user_settings/profile")).to route_to('user_settings/profiles#update')
     expect(patch("/-/user_settings/profile")).to route_to('user_settings/profiles#update')
   end
@@ -149,11 +149,11 @@ end
 #                     PATCH    /-/profile/preferences(.:format) profiles/preferences#update
 #                     PUT      /-/profile/preferences(.:format) profiles/preferences#update
 RSpec.describe Profiles::PreferencesController, 'routing' do
-  it 'to #show' do
+  specify 'to #show' do
     expect(get('/-/profile/preferences')).to route_to('profiles/preferences#show')
   end
 
-  it 'to #update' do
+  specify 'to #update' do
     expect(put('/-/profile/preferences')).to   route_to('profiles/preferences#update')
     expect(patch('/-/profile/preferences')).to route_to('profiles/preferences#update')
   end
@@ -166,19 +166,19 @@ end
 #          PUT    /-/user_settings/ssh_keys/:id(.:format)      keys#update
 #          DELETE /-/user_settings/ssh_keys/:id(.:format)      keys#destroy
 RSpec.describe UserSettings::SshKeysController, "routing", feature_category: :system_access do
-  it "to #index" do
+  specify "to #index" do
     expect(get("/-/user_settings/ssh_keys")).to route_to('user_settings/ssh_keys#index')
   end
 
-  it "to #create" do
+  specify "to #create" do
     expect(post("/-/user_settings/ssh_keys")).to route_to('user_settings/ssh_keys#create')
   end
 
-  it "to #show" do
+  specify "to #show" do
     expect(get("/-/user_settings/ssh_keys/1")).to route_to('user_settings/ssh_keys#show', id: '1')
   end
 
-  it "to #destroy" do
+  specify "to #destroy" do
     expect(delete("/-/user_settings/ssh_keys/1")).to route_to('user_settings/ssh_keys#destroy', id: '1')
   end
 end
@@ -188,15 +188,15 @@ end
 #      PUT    /-/profile/gpg_keys/:id  gpg_keys#revoke
 #      DELETE /-/profile/gpg_keys/:id  gpg_keys#desroy
 RSpec.describe UserSettings::GpgKeysController, "routing", feature_category: :system_access do
-  it "to #index" do
+  specify "to #index" do
     expect(get("/-/user_settings/gpg_keys")).to route_to('user_settings/gpg_keys#index')
   end
 
-  it "to #create" do
+  specify "to #create" do
     expect(post("/-/user_settings/gpg_keys")).to route_to('user_settings/gpg_keys#create')
   end
 
-  it "to #destroy" do
+  specify "to #destroy" do
     expect(delete("/-/user_settings/gpg_keys/1")).to route_to('user_settings/gpg_keys#destroy', id: '1')
   end
 end
@@ -205,22 +205,22 @@ end
 #          POST   /-/profile/emails(.:format)          emails#create
 #          DELETE /-/profile/emails/:id(.:format)      keys#destroy
 RSpec.describe Profiles::EmailsController, "routing" do
-  it "to #index" do
+  specify "to #index" do
     expect(get("/-/profile/emails")).to route_to('profiles/emails#index')
   end
 
-  it "to #create" do
+  specify "to #create" do
     expect(post("/-/profile/emails")).to route_to('profiles/emails#create')
   end
 
-  it "to #destroy" do
+  specify "to #destroy" do
     expect(delete("/-/profile/emails/1")).to route_to('profiles/emails#destroy', id: '1')
   end
 end
 
 # profile_avatar DELETE /-/profile/avatar(.:format) profiles/avatars#destroy
 RSpec.describe Profiles::AvatarsController, "routing" do
-  it "to #destroy" do
+  specify "to #destroy" do
     expect(delete("/-/profile/avatar")).to route_to('profiles/avatars#destroy')
   end
 end
@@ -229,7 +229,7 @@ end
 #         dashboard_issues GET    /dashboard/issues(.:format)         dashboard#issues
 # dashboard_merge_requests GET    /dashboard/merge_requests(.:format) dashboard#merge_requests
 RSpec.describe DashboardController, "routing" do
-  it "to #index" do
+  specify "to #index" do
     expect(get("/dashboard")).to route_to('dashboard/projects#index')
     expect(get("/dashboard/projects")).to route_to('dashboard/projects#index')
     expect(get("/dashboard/projects/contributed")).to route_to('dashboard/projects#index')
@@ -238,22 +238,22 @@ RSpec.describe DashboardController, "routing" do
     expect(get("/dashboard/projects/inactive")).to route_to('dashboard/projects#index')
   end
 
-  it "to #issues" do
+  specify "to #issues" do
     expect(get("/dashboard/issues.html")).to route_to('dashboard#issues', format: 'html')
   end
 
-  it "to #calendar_issues" do
+  specify "to #calendar_issues" do
     expect(get("/dashboard/issues.ics")).to route_to('dashboard#issues_calendar', format: 'ics')
   end
 
-  it "to #merge_requests" do
+  specify "to #merge_requests" do
     expect(get("/dashboard/merge_requests")).to route_to('dashboard#merge_requests')
   end
 end
 
 #                     root        /                                   root#show
 RSpec.describe RootController, 'routing' do
-  it 'to #index' do
+  specify 'to #index' do
     expect(get('/')).to route_to('root#index')
   end
 end
@@ -336,7 +336,7 @@ RSpec.describe "Authentication", "routing" do
 end
 
 RSpec.describe HealthCheckController, 'routing' do
-  it 'to #index' do
+  specify 'to #index' do
     expect(get('/health_check')).to route_to('health_check#index')
   end
 
@@ -348,50 +348,50 @@ end
 RSpec.describe InvitesController, 'routing' do
   let_it_be(:member) { create(:project_member, :invited) }
 
-  it 'to #show' do
+  specify 'to #show' do
     expect(get("/-/invites/#{member.invite_token}")).to route_to('invites#show', id: member.invite_token)
   end
 end
 
 RSpec.describe SentNotificationsController, 'routing' do
-  it 'to #unsubscribe' do
+  specify 'to #unsubscribe' do
     expect(get("/-/sent_notifications/4bee17d4a63ed60cf5db53417e9aeb4c/unsubscribe"))
       .to route_to('sent_notifications#unsubscribe', id: '4bee17d4a63ed60cf5db53417e9aeb4c')
   end
 end
 
 RSpec.describe AutocompleteController, 'routing' do
-  it 'to #users' do
+  specify 'to #users' do
     expect(get("/-/autocomplete/users")).to route_to('autocomplete#users')
   end
 
-  it 'to #projects' do
+  specify 'to #projects' do
     expect(get("/-/autocomplete/projects")).to route_to('autocomplete#projects')
   end
 
-  it 'to #award_emojis' do
+  specify 'to #award_emojis' do
     expect(get("/-/autocomplete/award_emojis")).to route_to('autocomplete#award_emojis')
   end
 
-  it 'to #merge_request_target_branches' do
+  specify 'to #merge_request_target_branches' do
     expect(get("/-/autocomplete/merge_request_target_branches")).to route_to('autocomplete#merge_request_target_branches')
   end
 end
 
 RSpec.describe SandboxController, 'routing' do
-  it 'to #mermaid' do
+  specify 'to #mermaid' do
     expect(get("/-/sandbox/mermaid")).to route_to('sandbox#mermaid')
   end
 end
 
 RSpec.describe Snippets::BlobsController, "routing" do
-  it "to #raw" do
+  specify "to #raw" do
     expect(get('/-/snippets/1/raw/master/lib/version.rb'))
       .to route_to('snippets/blobs#raw', snippet_id: '1', ref: 'master', path: 'lib/version.rb')
   end
 
   context 'when reference has special symbols' do
-    it "to #raw" do
+    specify "to #raw" do
       expect(get('/-/snippets/1/raw/0.0.x-rc/lib/version.rb'))
         .to route_to('snippets/blobs#raw', snippet_id: '1', ref: '0.0.x-rc', path: 'lib/version.rb')
     end
@@ -399,14 +399,14 @@ RSpec.describe Snippets::BlobsController, "routing" do
 end
 
 RSpec.describe RunnerSetupController, 'routing' do
-  it 'to #platforms' do
+  specify 'to #platforms' do
     expect(get("/-/runner_setup/platforms")).to route_to('runner_setup#platforms')
   end
 end
 
 # jwks  GET /-/jwks(.:format)  jwks#index
 RSpec.describe JwksController, "routing" do
-  it "to #index" do
+  specify "to #index" do
     expect(get('/-/jwks')).to route_to('jwks#index')
   end
 end
@@ -414,7 +414,7 @@ end
 # user_settings_authentication_log GET  /-/user_settings/authentication_log(.:format) user_settings/user_settings#authentication_log
 
 RSpec.describe UserSettings::UserSettingsController, 'routing', feature_category: :system_access do
-  it 'to #authentication_log' do
+  specify 'to #authentication_log' do
     expect(get('/-/user_settings/authentication_log')).to route_to('user_settings/user_settings#authentication_log')
   end
 end
@@ -422,7 +422,7 @@ end
 # user_settings_active_sessions_log GET /-/user_settings_active_sessions_log(.:format)  user_settings/active_sessions#index#
 
 RSpec.describe UserSettings::ActiveSessionsController, 'routing', feature_category: :system_access do
-  it 'to #index' do
+  specify 'to #index' do
     expect(get('/-/user_settings/active_sessions')).to route_to('user_settings/active_sessions#index')
   end
 end
