@@ -9,6 +9,10 @@ RSpec.describe MergeRequests::PipelineEntity, feature_category: :continuous_inte
 
   let(:request) { double('request') }
 
+  let(:entity) do
+    described_class.represent(pipeline, request: request)
+  end
+
   before_all do
     project.add_guest(user)
   end
@@ -21,10 +25,6 @@ RSpec.describe MergeRequests::PipelineEntity, feature_category: :continuous_inte
     allow(pipeline).to receive(:coverage).and_return(35.0)
   end
 
-  let(:entity) do
-    described_class.represent(pipeline, request: request)
-  end
-
   subject { entity.as_json }
 
   describe '#as_json' do
@@ -60,16 +60,6 @@ RSpec.describe MergeRequests::PipelineEntity, feature_category: :continuous_inte
       let_it_be(:child_pipeline) { create(:ci_pipeline, child_of: pipeline) }
       let_it_be(:child_build_with_artifact) { create(:ci_build, :test_reports, pipeline: child_pipeline) }
 
-      context 'when show_child_reports_in_mr_page feature is disabled' do
-        before do
-          stub_feature_flags(show_child_reports_in_mr_page: false)
-        end
-
-        it 'gets artifacts from itself' do
-          expect(entity.as_json[:details][:artifacts].pluck(:name)).to match_array(["test:codequality"])
-        end
-      end
-
       it 'gets artifacts from itself and child pipelines' do
         expect(entity.as_json[:details][:artifacts].pluck(:name)).to match_array(["test:codequality", "test:junit"])
       end
