@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-RSpec.describe ::Ci::Runners::SetRunnerAssociatedProjectsService, '#execute', feature_category: :runner do
+RSpec.describe ::Ci::Runners::SetRunnerAssociatedProjectsService, '#execute', feature_category: :runner_core do
   subject(:execute) do
     described_class.new(runner: runner, current_user: user, project_ids: new_projects.map(&:id)).execute.tap do
       # Ensure we're recomputing the owner value
