@@ -126,7 +126,7 @@ RSpec.describe MergeRequests::PushOptionsHandlerService, feature_category: :sour
     end
   end
 
-  shared_examples_for 'a service that can set the merge request to merge when pipeline succeeds' do
+  shared_examples_for 'a service that can set the merge request to auto merge' do
     subject(:last_mr) { MergeRequest.last }
 
     let(:change) { Gitlab::ChangesList.new(changes).changes.first }
@@ -210,6 +210,48 @@ RSpec.describe MergeRequests::PushOptionsHandlerService, feature_category: :sour
     it_behaves_like 'with the project default branch'
   end
 
+  describe '`auto_merge` push option' do
+    let(:push_options) { { auto_merge: true } }
+
+    context 'with a new branch' do
+      let(:changes) { new_branch_changes }
+
+      it_behaves_like 'a service that does not create a merge request'
+
+      it 'adds an error to the service' do
+        service.execute
+
+        expect(service.errors).to include(error_mr_required)
+      end
+
+      context 'when coupled with the `create` push option' do
+        let(:push_options) { { create: true, auto_merge: true } }
+
+        it_behaves_like 'a service that can create a merge request'
+        it_behaves_like 'a service that can set the merge request to auto merge'
+      end
+    end
+
+    context 'with an existing branch but no open MR' do
+      let(:changes) { existing_branch_changes }
+
+      it_behaves_like 'a service that does not create a merge request'
+
+      it 'adds an error to the service' do
+        service.execute
+
+        expect(service.errors).to include(error_mr_required)
+      end
+
+      context 'when coupled with the `create` push option' do
+        let(:push_options) { { create: true, auto_merge: true } }
+
+        it_behaves_like 'a service that can create a merge request'
+        it_behaves_like 'a service that can set the merge request to auto merge'
+      end
+    end
+  end
+
   describe '`merge_when_pipeline_succeeds` push option' do
     let(:push_options) { { merge_when_pipeline_succeeds: true } }
 
@@ -228,7 +270,7 @@ RSpec.describe MergeRequests::PushOptionsHandlerService, feature_category: :sour
         let(:push_options) { { create: true, merge_when_pipeline_succeeds: true } }
 
         it_behaves_like 'a service that can create a merge request'
-        it_behaves_like 'a service that can set the merge request to merge when pipeline succeeds'
+        it_behaves_like 'a service that can set the merge request to auto merge'
       end
     end
 
@@ -247,7 +289,7 @@ RSpec.describe MergeRequests::PushOptionsHandlerService, feature_category: :sour
         let(:push_options) { { create: true, merge_when_pipeline_succeeds: true } }
 
         it_behaves_like 'a service that can create a merge request'
-        it_behaves_like 'a service that can set the merge request to merge when pipeline succeeds'
+        it_behaves_like 'a service that can set the merge request to auto merge'
       end
     end
 
@@ -256,7 +298,7 @@ RSpec.describe MergeRequests::PushOptionsHandlerService, feature_category: :sour
       let!(:merge_request) { create(:merge_request, source_project: project, source_branch: source_branch) }
 
       it_behaves_like 'a service that does not create a merge request'
-      it_behaves_like 'a service that can set the merge request to merge when pipeline succeeds'
+      it_behaves_like 'a service that can set the merge request to auto merge'
     end
 
     it_behaves_like 'with a deleted branch'
@@ -316,6 +358,23 @@ RSpec.describe MergeRequests::PushOptionsHandlerService, feature_category: :sour
     it_behaves_like 'with the project default branch'
   end
 
+  describe 'pushing from default branch' do
+    let(:changes) { default_branch_changes }
+
+    context 'with target branch specified' do
+      let(:push_options) { { create: true, target: target_branch } }
+
+      it_behaves_like 'a service that can create a merge request'
+      it_behaves_like 'a service that can set the target of a merge request'
+    end
+
+    context 'without target branch specified' do
+      let(:push_options) { { create: true } }
+
+      it_behaves_like 'a service that does nothing'
+    end
+  end
+
   describe '`target` push option' do
     let(:push_options) { { target: target_branch } }
 
