@@ -1001,90 +1001,6 @@ RSpec.describe Projects::UpdateService, feature_category: :groups_and_projects d
         end
       end
     end
-
-    describe 'with `remove_deletion_schedule` param' do
-      subject(:service_action) { update_project(project, admin, **params) }
-
-      context 'when true' do
-        let(:params) { { remove_deletion_schedule: true } }
-
-        context 'when project is marked for deletion' do
-          let_it_be_with_reload(:project) { create(:project, :aimed_for_deletion) }
-
-          it 'destroys deletion schedule' do
-            service_action
-
-            expect(project.project_namespace.reload.deletion_schedule).to be_nil
-          end
-
-          context 'when deletion schedule destroy failed' do
-            before do
-              allow(project.deletion_schedule)
-                .to receive(:destroy!).and_raise(ActiveRecord::RecordNotDestroyed, 'destroy failed')
-            end
-
-            it 'returns error result', :aggregate_failures do
-              result = service_action
-
-              expect(result[:status]).to eq(:error)
-              expect(result[:message]).to eq('Project could not be updated!')
-            end
-
-            it 'does not destroy deletion schedule' do
-              service_action
-
-              expect(project.project_namespace.reload.deletion_schedule).not_to be_nil
-            end
-
-            context 'when updating other columns' do
-              let(:params) { { remove_deletion_schedule: true, description: 'new' } }
-
-              it 'does not persist other changes' do
-                service_action
-
-                expect(project.reload.description).not_to eq('new')
-              end
-            end
-          end
-
-          context 'when `replicate_deletion_schedule_operations` flag is disabled' do
-            before do
-              stub_feature_flags(replicate_deletion_schedule_operations: false)
-            end
-
-            it 'does not destroy deletion schedule', :aggregate_failures do
-              result = service_action
-
-              expect(result[:status]).to eq(:success)
-              expect(project.project_namespace.reload.deletion_schedule).not_to be_nil
-            end
-          end
-        end
-
-        context 'when project is not marked for deletion' do
-          let_it_be(:project) { create(:project) }
-
-          it 'does not raise error' do
-            result = service_action
-
-            expect(result[:status]).to eq(:success)
-          end
-        end
-      end
-
-      context 'when false' do
-        let_it_be(:project) { create(:project, :aimed_for_deletion) }
-
-        let(:params) { { remove_deletion_schedule: false } }
-
-        it 'does not destroy deletion schedule', :aggregate_failures do
-          result = service_action
-
-          expect(result[:status]).to eq(:success)
-          expect(project.project_namespace.reload.deletion_schedule).not_to be_nil
-        end
-      end
-    end
   end
 
   describe '#run_auto_devops_pipeline?' do
