@@ -1,6 +1,12 @@
 # frozen_string_literal: true
 
 RSpec.shared_examples 'no work items in the list' do
+  it 'shows message when there are no items in the list' do
+    expect(page).to have_content("Track bugs, plan features, and organize your work with issues ")
+  end
+end
+
+RSpec.shared_examples 'no work items in search results' do
   it 'shows message when there are no items in the list' do
     expect(page).to have_content("No results found")
   end
@@ -121,4 +127,11 @@ RSpec.shared_examples 'parent filter' do
     expect(page).to have_link(work_item_2.title)
     expect(page).not_to have_link(child_item.title)
   end
+
+  it 'shows parent in the filtered search dropdown' do
+    select_tokens 'Parent', '='
+
+    # "None", "Any", "Epic without parent", "Child epic" and "Parent epic"
+    expect_suggestion_count expected_count
+  end
 end
