@@ -38,6 +38,7 @@ RSpec.shared_examples "a user type with merge request interaction type" do
       starredProjects
       contributedProjects
       callouts
+      groupCallouts
       merge_request_interaction
       namespace
       timelogs
@@ -61,6 +62,7 @@ RSpec.shared_examples "a user type with merge request interaction type" do
       ide
       userPreferences
       type
+      personalAccessTokens
     ]
 
     # TODO: 'workspaces' needs to be included, but only when this spec is run in EE context, to account for the
