@@ -7,7 +7,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks non-member abilities' do
-      # disallowed
       expect(permissions(non_member_user, work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji
@@ -20,7 +19,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks project guest abilities' do
-      # disallowed
       expect(permissions(guest, not_persisted_work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji,
@@ -39,7 +37,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks project planner abilities' do
-      # disallowed
       expect(permissions(planner, work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji
@@ -52,7 +49,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks project reporter abilities' do
-      # disallowed
       expect(permissions(reporter, work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji,
@@ -66,7 +62,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks group guest abilities' do
-      # disallowed
       expect(permissions(group_guest, work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji,
@@ -90,7 +85,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks group planner abilities' do
-      # disallowed
       expect(permissions(group_planner, work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji,
@@ -104,7 +98,6 @@ RSpec.shared_examples 'abilities without group level work items license' do
     end
 
     it 'checks group reporter abilities' do
-      # disallowed
       expect(permissions(group_reporter, work_item)).to be_disallowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :delete_work_item,
         :admin_parent_link, :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji,
@@ -126,13 +119,11 @@ RSpec.shared_examples 'abilities with group level work items license' do
     end
 
     it 'checks project guest abilities' do
-      # allowed
       expect(permissions(guest, not_persisted_work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :create_note, :award_emoji)
       expect(permissions(guest, work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :create_note, :award_emoji)
 
-      # disallowed
       expect(permissions(guest, not_persisted_work_item)).to be_disallowed(
         :admin_work_item, :update_work_item, :delete_work_item, :admin_parent_link, :set_work_item_metadata,
         :admin_work_item_link, :move_work_item, :clone_work_item
@@ -148,12 +139,10 @@ RSpec.shared_examples 'abilities with group level work items license' do
     end
 
     it 'checks project planner abilities' do
-      # allowed
       expect(permissions(planner, work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :create_note, :award_emoji
       )
 
-      # disallowed
       expect(permissions(planner, work_item)).to be_disallowed(
         :admin_work_item, :update_work_item, :delete_work_item, :admin_parent_link, :set_work_item_metadata,
         :admin_work_item_link, :move_work_item, :clone_work_item
@@ -165,12 +154,10 @@ RSpec.shared_examples 'abilities with group level work items license' do
     end
 
     it 'checks project reporter abilities' do
-      # allowed
       expect(permissions(reporter, work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :create_note, :award_emoji
       )
 
-      # disallowed
       expect(permissions(reporter, work_item)).to be_disallowed(
         :admin_work_item, :update_work_item, :delete_work_item, :admin_parent_link, :set_work_item_metadata,
         :admin_work_item_link, :move_work_item, :clone_work_item
@@ -182,7 +169,6 @@ RSpec.shared_examples 'abilities with group level work items license' do
     end
 
     it 'checks group guest abilities' do
-      # allowed
       expect(permissions(group_guest, not_persisted_work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :admin_parent_link, :set_work_item_metadata, :admin_work_item_link,
         :create_note, :award_emoji
@@ -199,7 +185,6 @@ RSpec.shared_examples 'abilities with group level work items license' do
         :admin_work_item_link, :create_note, :award_emoji
       )
 
-      # disallowed
       expect(permissions(group_guest, work_item)).to be_disallowed(
         :admin_work_item, :update_work_item, :delete_work_item, :set_work_item_metadata,
         :move_work_item, :clone_work_item
@@ -217,7 +202,6 @@ RSpec.shared_examples 'abilities with group level work items license' do
     end
 
     it 'checks group planner abilities' do
-      # allowed
       expect(permissions(group_planner, work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :admin_parent_link,
         :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji, :move_work_item, :clone_work_item
@@ -227,13 +211,11 @@ RSpec.shared_examples 'abilities with group level work items license' do
         :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji, :move_work_item, :clone_work_item
       )
 
-      # disallowed
-      expect(permissions(group_planner, work_item)).to be_disallowed(:delete_work_item)
-      expect(permissions(group_planner, confidential_work_item)).to be_disallowed(:delete_work_item)
+      expect(permissions(group_planner, work_item)).to be_allowed(:delete_work_item)
+      expect(permissions(group_planner, confidential_work_item)).to be_allowed(:delete_work_item)
     end
 
     it 'checks group reporter abilities' do
-      # allowed
       expect(permissions(group_reporter, work_item)).to be_allowed(
         :read_work_item, :read_issue, :read_note, :admin_work_item, :update_work_item, :admin_parent_link,
         :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji, :move_work_item, :clone_work_item
@@ -243,7 +225,6 @@ RSpec.shared_examples 'abilities with group level work items license' do
         :set_work_item_metadata, :admin_work_item_link, :create_note, :award_emoji, :move_work_item, :clone_work_item
       )
 
-      # disallowed
       expect(permissions(group_reporter, work_item)).to be_disallowed(:delete_work_item)
       expect(permissions(group_reporter, confidential_work_item)).to be_disallowed(:delete_work_item)
     end
