@@ -367,11 +367,13 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'MergeRequests::HandleAssigneesChangeWorker' => 3,
         'MergeRequests::MergeabilityCheckBatchWorker' => 3,
         'MergeRequests::ResolveTodosWorker' => 3,
+        'MergeRequests::ShipMergeRequestWorker' => 3,
         'MergeRequests::SyncCodeOwnerApprovalRulesWorker' => 3,
         'MergeTrains::RefreshWorker' => 3,
         'MergeWorker' => 3,
         'MigrateExternalDiffsWorker' => 3,
         'Onboarding::ProgressTrackingWorker' => 3,
+        'Observability::CreateGroupO11ySettingWorker' => 3,
         'Namespaces::RootStatisticsWorker' => 3,
         'Namespaces::ScheduleAggregationWorker' => 3,
         'Namespaces::RemoveDormantMembersWorker' => 0,
@@ -478,7 +480,6 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'SyncSeatLinkRequestWorker' => 20,
         'SyncSeatLinkWorker' => 12,
         'SystemHookPushWorker' => 3,
-        'TodosDestroyer::ConfidentialEpicWorker' => 3,
         'TodosDestroyer::ConfidentialIssueWorker' => 3,
         'TodosDestroyer::DestroyedIssuableWorker' => 3,
         'TodosDestroyer::DestroyedDesignsWorker' => 3,
@@ -494,9 +495,12 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'UploadChecksumWorker' => 3,
         'Import::ReassignPlaceholderUserRecordsWorker' => 5,
         'Vulnerabilities::Statistics::AdjustmentWorker' => 3,
+        'Vulnerabilities::UpdateArchivedAttributeOfVulnerabilityStatisticsWorker' => 2,
+        'Vulnerabilities::UpdateArchivedAttributeOfVulnerabilityReadsWorker' => 2,
         'VulnerabilityExports::ExportDeletionWorker' => 3,
         'VulnerabilityExports::ExportWorker' => 3,
         'VirtualRegistries::Packages::Cache::DestroyOrphanEntriesWorker' => 0,
+        'VirtualRegistries::Cleanup::ExecutePolicyWorker' => 0,
         'WaitForClusterCreationWorker' => 3,
         'WebHookWorker' => 4,
         'WebHooks::LogExecutionWorker' => 3,
